Module: Aws::ElastiCache

Defined in:
lib/aws-sdk-elasticache/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/params.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-elasticache/plugins/endpoints.rb,
lib/aws-sdk-elasticache/endpoint_provider.rb,
lib/aws-sdk-elasticache/client_api.rb,
lib/aws-sdk-elasticache/endpoints.rb,
lib/aws-sdk-elasticache/resource.rb,
lib/aws-sdk-elasticache/waiters.rb,
lib/aws-sdk-elasticache/errors.rb,
lib/aws-sdk-elasticache/client.rb,
lib/aws-sdk-elasticache/types.rb,
lib/aws-sdk-elasticache.rb

Overview

This module provides support for Amazon ElastiCache. This module is available in the aws-sdk-elasticache gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

elasticache = Aws::ElastiCache::Client.new
resp = elasticache.add_tags_to_resource(params)

See Client for more information.

Errors

Errors returned from Amazon ElastiCache are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::ElastiCache::Errors::ServiceError
  # rescues all Amazon ElastiCache API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Params, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.147.0'