Class: Aws::ElastiCache::Types::CacheCluster
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::CacheCluster
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Contains all of the attributes of a specific cluster.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN (Amazon Resource Name) of the cache cluster.
-
#at_rest_encryption_enabled ⇒ Boolean
A flag that enables encryption at-rest when set to
true. -
#auth_token_enabled ⇒ Boolean
A flag that enables using an
AuthToken(password) when issuing Redis commands. -
#auth_token_last_modified_date ⇒ Time
The date the auth token was last modified.
-
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign.
-
#cache_cluster_create_time ⇒ Time
The date and time when the cluster was created.
-
#cache_cluster_id ⇒ String
The user-supplied identifier of the cluster.
-
#cache_cluster_status ⇒ String
The current state of this cluster, one of the following values:
available,creating,deleted,deleting,incompatible-network,modifying, ‘rebooting cluster nodes`,restore-failed, orsnapshotting. -
#cache_node_type ⇒ String
The name of the compute and memory capacity node type for the cluster.
-
#cache_nodes ⇒ Array<Types::CacheNode>
A list of cache nodes that are members of the cluster.
-
#cache_parameter_group ⇒ Types::CacheParameterGroupStatus
Status of the cache parameter group.
-
#cache_security_groups ⇒ Array<Types::CacheSecurityGroupMembership>
A list of cache security group elements, composed of name and status sub-elements.
-
#cache_subnet_group_name ⇒ String
The name of the cache subnet group associated with the cluster.
-
#client_download_landing_page ⇒ String
The URL of the web page where you can download the latest ElastiCache client library.
-
#configuration_endpoint ⇒ Types::Endpoint
Represents a Memcached cluster endpoint which can be used by an application to connect to any node in the cluster.
-
#engine ⇒ String
The name of the cache engine (
memcachedorredis) to be used for this cluster. -
#engine_version ⇒ String
The version of the cache engine that is used in this cluster.
-
#ip_discovery ⇒ String
The network type associated with the cluster, either
ipv4|ipv6. -
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfiguration>
Returns the destination, format and type of the logs.
-
#network_type ⇒ String
Must be either
ipv4|ipv6|dual_stack. -
#notification_configuration ⇒ Types::NotificationConfiguration
Describes a notification topic and its status.
-
#num_cache_nodes ⇒ Integer
The number of cache nodes in the cluster.
-
#pending_modified_values ⇒ Types::PendingModifiedValues
A group of settings that are applied to the cluster in the future, or that are currently being applied.
-
#preferred_availability_zone ⇒ String
The name of the Availability Zone in which the cluster is located or “Multiple” if the cache nodes are located in different Availability Zones.
-
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed.
-
#preferred_outpost_arn ⇒ String
The outpost ARN in which the cache cluster is created.
-
#replication_group_id ⇒ String
The replication group to which this cluster belongs.
-
#replication_group_log_delivery_enabled ⇒ Boolean
A boolean value indicating whether log delivery is enabled for the replication group.
-
#security_groups ⇒ Array<Types::SecurityGroupMembership>
A list of VPC Security Groups associated with the cluster.
-
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic cluster snapshots before deleting them.
-
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your cluster.
-
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to
true.
Instance Attribute Details
#arn ⇒ String
The ARN (Amazon Resource Name) of the cache cluster.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#at_rest_encryption_enabled ⇒ Boolean
A flag that enables encryption at-rest when set to true.
You cannot modify the value of AtRestEncryptionEnabled after the cluster is created. To enable at-rest encryption on a cluster you must set AtRestEncryptionEnabled to true when you create a cluster.
Required: Only available when creating a replication group in an Amazon VPC using redis version 3.2.6, 4.x or later.
Default: false
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auth_token_enabled ⇒ Boolean
A flag that enables using an AuthToken (password) when issuing Redis commands.
Default: false
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auth_token_last_modified_date ⇒ Time
The date the auth token was last modified
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign. This parameter is disabled for previous versions.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_cluster_create_time ⇒ Time
The date and time when the cluster was created.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_cluster_id ⇒ String
The user-supplied identifier of the cluster. This identifier is a unique key that identifies a cluster.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_cluster_status ⇒ String
The current state of this cluster, one of the following values: available, creating, deleted, deleting, incompatible-network, modifying, ‘rebooting cluster nodes`, restore-failed, or snapshotting.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
The name of the compute and memory capacity node type for the cluster.
The following node types are supported by ElastiCache. Generally speaking, the current generation types provide more memory and computational power at lower cost when compared to their equivalent previous generation counterparts.
-
General purpose:
-
Current generation:
**M6g node types** (available only for Redis engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward):
cache.m6g.large,cache.m6g.xlarge,cache.m6g.2xlarge,cache.m6g.4xlarge,cache.m6g.8xlarge,cache.m6g.12xlarge,cache.m6g.16xlarge<note markdown=“1”> For region availability, see [Supported Node Types]
</note>**M5 node types:**
cache.m5.large,cache.m5.xlarge,cache.m5.2xlarge,cache.m5.4xlarge,cache.m5.12xlarge,cache.m5.24xlarge**M4 node types:**
cache.m4.large,cache.m4.xlarge,cache.m4.2xlarge,cache.m4.4xlarge,cache.m4.10xlarge**T4g node types** (available only for Redis engine version 5.0.6 onward and Memcached engine version 1.5.16 onward):
cache.t4g.micro,cache.t4g.small,cache.t4g.medium**T3 node types:**
cache.t3.micro,cache.t3.small,cache.t3.medium**T2 node types:**
cache.t2.micro,cache.t2.small,cache.t2.medium -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**T1 node types:**
cache.t1.micro**M1 node types:**
cache.m1.small,cache.m1.medium,cache.m1.large,cache.m1.xlarge**M3 node types:**
cache.m3.medium,cache.m3.large,cache.m3.xlarge,cache.m3.2xlarge
-
-
Compute optimized:
-
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**C1 node types:**
cache.c1.xlarge
-
-
Memory optimized:
-
Current generation:
**R6g node types** (available only for Redis engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward).
cache.r6g.large,cache.r6g.xlarge,cache.r6g.2xlarge,cache.r6g.4xlarge,cache.r6g.8xlarge,cache.r6g.12xlarge,cache.r6g.16xlarge<note markdown=“1”> For region availability, see [Supported Node Types]
</note>**R5 node types:**
cache.r5.large,cache.r5.xlarge,cache.r5.2xlarge,cache.r5.4xlarge,cache.r5.12xlarge,cache.r5.24xlarge**R4 node types:**
cache.r4.large,cache.r4.xlarge,cache.r4.2xlarge,cache.r4.4xlarge,cache.r4.8xlarge,cache.r4.16xlarge -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**M2 node types:**
cache.m2.xlarge,cache.m2.2xlarge,cache.m2.4xlarge**R3 node types:**
cache.r3.large,cache.r3.xlarge,cache.r3.2xlarge,cache.r3.4xlarge,cache.r3.8xlarge
-
**Additional node type info**
-
All current generation instance types are created in Amazon VPC by default.
-
Redis append-only files (AOF) are not supported for T1 or T2 instances.
-
Redis Multi-AZ with automatic failover is not supported on T1 instances.
-
Redis configuration variables
appendonlyandappendfsyncare not supported on Redis version 2.8.22 and later.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_nodes ⇒ Array<Types::CacheNode>
A list of cache nodes that are members of the cluster.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_parameter_group ⇒ Types::CacheParameterGroupStatus
Status of the cache parameter group.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_security_groups ⇒ Array<Types::CacheSecurityGroupMembership>
A list of cache security group elements, composed of name and status sub-elements.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_subnet_group_name ⇒ String
The name of the cache subnet group associated with the cluster.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#client_download_landing_page ⇒ String
The URL of the web page where you can download the latest ElastiCache client library.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#configuration_endpoint ⇒ Types::Endpoint
Represents a Memcached cluster endpoint which can be used by an application to connect to any node in the cluster. The configuration endpoint will always have .cfg in it.
Example: mem-3.9dvc4r.cfg.usw2.cache.amazonaws.com:11211
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the cache engine (memcached or redis) to be used for this cluster.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version of the cache engine that is used in this cluster.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#ip_discovery ⇒ String
The network type associated with the cluster, either ipv4 | ipv6. IPv6 is supported for workloads using Redis engine version 6.2 onward or Memcached engine version 1.6.6 on all instances built on the [Nitro system].
[1]: aws.amazon.com/ec2/nitro/
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfiguration>
Returns the destination, format and type of the logs.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Must be either ipv4 | ipv6 | dual_stack. IPv6 is supported for workloads using Redis engine version 6.2 onward or Memcached engine version 1.6.6 on all instances built on the [Nitro system].
[1]: aws.amazon.com/ec2/nitro/
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#notification_configuration ⇒ Types::NotificationConfiguration
Describes a notification topic and its status. Notification topics are used for publishing ElastiCache events to subscribers using Amazon Simple Notification Service (SNS).
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#num_cache_nodes ⇒ Integer
The number of cache nodes in the cluster.
For clusters running Redis, this value must be 1. For clusters running Memcached, this value must be between 1 and 40.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#pending_modified_values ⇒ Types::PendingModifiedValues
A group of settings that are applied to the cluster in the future, or that are currently being applied.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_availability_zone ⇒ String
The name of the Availability Zone in which the cluster is located or “Multiple” if the cache nodes are located in different Availability Zones.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.
Valid values for ddd are:
-
sun -
mon -
tue -
wed -
thu -
fri -
sat
Example: sun:23:00-mon:01:30
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_outpost_arn ⇒ String
The outpost ARN in which the cache cluster is created.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The replication group to which this cluster belongs. If this field is empty, the cluster is not associated with any replication group.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#replication_group_log_delivery_enabled ⇒ Boolean
A boolean value indicating whether log delivery is enabled for the replication group.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<Types::SecurityGroupMembership>
A list of VPC Security Groups associated with the cluster.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic cluster snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.
If the value of SnapshotRetentionLimit is set to zero (0), backups are turned off.
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your cluster.
Example: 05:00-09:00
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true.
You cannot modify the value of TransitEncryptionEnabled after the cluster is created. To enable in-transit encryption on a cluster you must set TransitEncryptionEnabled to true when you create a cluster.
Required: Only available when creating a replication group in an Amazon VPC using redis version 3.2.6, 4.x or later.
Default: false
617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/aws-sdk-elasticache/types.rb', line 617 class CacheCluster < Struct.new( :cache_cluster_id, :configuration_endpoint, :client_download_landing_page, :cache_node_type, :engine, :engine_version, :cache_cluster_status, :num_cache_nodes, :preferred_availability_zone, :preferred_outpost_arn, :cache_cluster_create_time, :preferred_maintenance_window, :pending_modified_values, :notification_configuration, :cache_security_groups, :cache_parameter_group, :cache_subnet_group_name, :cache_nodes, :auto_minor_version_upgrade, :security_groups, :replication_group_id, :snapshot_retention_limit, :snapshot_window, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :arn, :replication_group_log_delivery_enabled, :log_delivery_configurations, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |