Class: Aws::ElastiCache::Types::CacheParameterGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Represents the output of a CreateCacheParameterGroup operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN (Amazon Resource Name) of the cache parameter group.

Returns:



1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'lib/aws-sdk-elasticache/types.rb', line 1074

class CacheParameterGroup < Struct.new(
  :cache_parameter_group_name,
  :cache_parameter_group_family,
  :description,
  :is_global,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#cache_parameter_group_familyString

The name of the cache parameter group family that this cache parameter group is compatible with.

Valid values are: memcached1.4 | memcached1.5 | memcached1.6 | redis2.6 | redis2.8 | redis3.2 | redis4.0 | redis5.0 | redis6.x |

Returns:



1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'lib/aws-sdk-elasticache/types.rb', line 1074

class CacheParameterGroup < Struct.new(
  :cache_parameter_group_name,
  :cache_parameter_group_family,
  :description,
  :is_global,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#cache_parameter_group_nameString

The name of the cache parameter group.

Returns:



1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'lib/aws-sdk-elasticache/types.rb', line 1074

class CacheParameterGroup < Struct.new(
  :cache_parameter_group_name,
  :cache_parameter_group_family,
  :description,
  :is_global,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description for this cache parameter group.

Returns:



1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'lib/aws-sdk-elasticache/types.rb', line 1074

class CacheParameterGroup < Struct.new(
  :cache_parameter_group_name,
  :cache_parameter_group_family,
  :description,
  :is_global,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#is_globalBoolean

Indicates whether the parameter group is associated with a Global datastore

Returns:



1074
1075
1076
1077
1078
1079
1080
1081
1082
# File 'lib/aws-sdk-elasticache/types.rb', line 1074

class CacheParameterGroup < Struct.new(
  :cache_parameter_group_name,
  :cache_parameter_group_family,
  :description,
  :is_global,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end