Class: Aws::ElastiCache::Types::CacheParameterGroupsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Represents the output of a DescribeCacheParameterGroups operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_parameter_groupsArray<Types::CacheParameterGroup>

A list of cache parameter groups. Each element in the list contains detailed information about one cache parameter group.

Returns:



1187
1188
1189
1190
1191
1192
# File 'lib/aws-sdk-elasticache/types.rb', line 1187

class CacheParameterGroupsMessage < Struct.new(
  :marker,
  :cache_parameter_groups)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Provides an identifier to allow retrieval of paginated results.

Returns:

  • (String)


1187
1188
1189
1190
1191
1192
# File 'lib/aws-sdk-elasticache/types.rb', line 1187

class CacheParameterGroupsMessage < Struct.new(
  :marker,
  :cache_parameter_groups)
  SENSITIVE = []
  include Aws::Structure
end