Class: Aws::ElastiCache::Types::CreateCacheClusterResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::CreateCacheClusterResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_cluster ⇒ Types::CacheCluster
Contains all of the attributes of a specific cluster.
Instance Attribute Details
#cache_cluster ⇒ Types::CacheCluster
Contains all of the attributes of a specific cluster.
2137 2138 2139 2140 2141 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2137 class CreateCacheClusterResult < Struct.new( :cache_cluster) SENSITIVE = [] include Aws::Structure end |