Class: Aws::ElastiCache::Types::CreateCacheSubnetGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Note:

When making an API call, you may pass CreateCacheSubnetGroupMessage data as a hash:

{
  cache_subnet_group_name: "String", # required
  cache_subnet_group_description: "String", # required
  subnet_ids: ["String"], # required
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
}

Represents the input of a CreateCacheSubnetGroup operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_subnet_group_descriptionString

A description for the cache subnet group.

Returns:

  • (String)


2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-elasticache/types.rb', line 2313

class CreateCacheSubnetGroupMessage < Struct.new(
  :cache_subnet_group_name,
  :cache_subnet_group_description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#cache_subnet_group_nameString

A name for the cache subnet group. This value is stored as a lowercase string.

Constraints: Must contain no more than 255 alphanumeric characters or hyphens.

Example: mysubnetgroup

Returns:

  • (String)


2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-elasticache/types.rb', line 2313

class CreateCacheSubnetGroupMessage < Struct.new(
  :cache_subnet_group_name,
  :cache_subnet_group_description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

A list of VPC subnet IDs for the cache subnet group.

Returns:

  • (Array<String>)


2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-elasticache/types.rb', line 2313

class CreateCacheSubnetGroupMessage < Struct.new(
  :cache_subnet_group_name,
  :cache_subnet_group_description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.

Returns:



2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/aws-sdk-elasticache/types.rb', line 2313

class CreateCacheSubnetGroupMessage < Struct.new(
  :cache_subnet_group_name,
  :cache_subnet_group_description,
  :subnet_ids,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end