Class: Aws::ElastiCache::Types::CreateServerlessCacheResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::CreateServerlessCacheResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#serverless_cache ⇒ Types::ServerlessCache
The response for the attempt to create the serverless cache.
Instance Attribute Details
#serverless_cache ⇒ Types::ServerlessCache
The response for the attempt to create the serverless cache.
3003 3004 3005 3006 3007 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3003 class CreateServerlessCacheResponse < Struct.new( :serverless_cache) SENSITIVE = [] include Aws::Structure end |