Class: Aws::ElastiCache::Types::CreateSnapshotMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Note:

When making an API call, you may pass CreateSnapshotMessage data as a hash:

{
  replication_group_id: "String",
  cache_cluster_id: "String",
  snapshot_name: "String", # required
  kms_key_id: "String",
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
}

Represents the input of a CreateSnapshot operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_cluster_idString

The identifier of an existing cluster. The snapshot is created from this cluster.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
3087
3088
3089
# File 'lib/aws-sdk-elasticache/types.rb', line 3081

class CreateSnapshotMessage < Struct.new(
  :replication_group_id,
  :cache_cluster_id,
  :snapshot_name,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ID of the KMS key used to encrypt the snapshot.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
3087
3088
3089
# File 'lib/aws-sdk-elasticache/types.rb', line 3081

class CreateSnapshotMessage < Struct.new(
  :replication_group_id,
  :cache_cluster_id,
  :snapshot_name,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#replication_group_idString

The identifier of an existing replication group. The snapshot is created from this replication group.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
3087
3088
3089
# File 'lib/aws-sdk-elasticache/types.rb', line 3081

class CreateSnapshotMessage < Struct.new(
  :replication_group_id,
  :cache_cluster_id,
  :snapshot_name,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_nameString

A name for the snapshot being created.

Returns:

  • (String)


3081
3082
3083
3084
3085
3086
3087
3088
3089
# File 'lib/aws-sdk-elasticache/types.rb', line 3081

class CreateSnapshotMessage < Struct.new(
  :replication_group_id,
  :cache_cluster_id,
  :snapshot_name,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.

Returns:



3081
3082
3083
3084
3085
3086
3087
3088
3089
# File 'lib/aws-sdk-elasticache/types.rb', line 3081

class CreateSnapshotMessage < Struct.new(
  :replication_group_id,
  :cache_cluster_id,
  :snapshot_name,
  :kms_key_id,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end