Class: Aws::ElastiCache::Types::CreateUserGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::CreateUserGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Note:
When making an API call, you may pass CreateUserGroupMessage data as a hash:
{
user_group_id: "String", # required
engine: "EngineType", # required
user_ids: ["UserId"],
tags: [
{
key: "String",
value: "String",
},
],
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine ⇒ String
The current supported value is Redis.
-
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource.
-
#user_group_id ⇒ String
The ID of the user group.
-
#user_ids ⇒ Array<String>
The list of user IDs that belong to the user group.
Instance Attribute Details
#engine ⇒ String
The current supported value is Redis.
3139 3140 3141 3142 3143 3144 3145 3146 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3139 class CreateUserGroupMessage < Struct.new( :user_group_id, :engine, :user_ids, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.
3139 3140 3141 3142 3143 3144 3145 3146 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3139 class CreateUserGroupMessage < Struct.new( :user_group_id, :engine, :user_ids, :tags) SENSITIVE = [] include Aws::Structure end |
#user_group_id ⇒ String
The ID of the user group.
3139 3140 3141 3142 3143 3144 3145 3146 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3139 class CreateUserGroupMessage < Struct.new( :user_group_id, :engine, :user_ids, :tags) SENSITIVE = [] include Aws::Structure end |
#user_ids ⇒ Array<String>
The list of user IDs that belong to the user group.
3139 3140 3141 3142 3143 3144 3145 3146 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3139 class CreateUserGroupMessage < Struct.new( :user_group_id, :engine, :user_ids, :tags) SENSITIVE = [] include Aws::Structure end |