Class: Aws::ElastiCache::Types::CreateUserMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Note:

When making an API call, you may pass CreateUserMessage data as a hash:

{
  user_id: "UserId", # required
  user_name: "UserName", # required
  engine: "EngineType", # required
  passwords: ["String"],
  access_string: "AccessString", # required
  no_password_required: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
  authentication_mode: {
    type: "password", # accepts password, no-password-required, iam
    passwords: ["String"],
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_stringString

Access permissions string used for this user.

Returns:

  • (String)


3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_modeTypes::AuthenticationMode

Specifies how to authenticate the user.



3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The current supported value is Redis.

Returns:

  • (String)


3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end

#no_password_requiredBoolean

Indicates a password is not required for this user.

Returns:

  • (Boolean)


3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end

#passwordsArray<String>

Passwords used for this user. You can create up to two passwords for each user.

Returns:

  • (Array<String>)


3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.

Returns:



3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The ID of the user.

Returns:

  • (String)


3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The username of the user.

Returns:

  • (String)


3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
# File 'lib/aws-sdk-elasticache/types.rb', line 3207

class CreateUserMessage < Struct.new(
  :user_id,
  :user_name,
  :engine,
  :passwords,
  :access_string,
  :no_password_required,
  :tags,
  :authentication_mode)
  SENSITIVE = []
  include Aws::Structure
end