Class: Aws::ElastiCache::Types::DecreaseNodeGroupsInGlobalReplicationGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DecreaseNodeGroupsInGlobalReplicationGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass DecreaseNodeGroupsInGlobalReplicationGroupMessage data as a hash:
{
global_replication_group_id: "String", # required
node_group_count: 1, # required
global_node_groups_to_remove: ["String"],
global_node_groups_to_retain: ["String"],
apply_immediately: false, # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
Indicates that the shard reconfiguration process begins immediately.
-
#global_node_groups_to_remove ⇒ Array<String>
If the value of NodeGroupCount is less than the current number of node groups (shards), then either NodeGroupsToRemove or NodeGroupsToRetain is required.
-
#global_node_groups_to_retain ⇒ Array<String>
If the value of NodeGroupCount is less than the current number of node groups (shards), then either NodeGroupsToRemove or NodeGroupsToRetain is required.
-
#global_replication_group_id ⇒ String
The name of the Global datastore.
-
#node_group_count ⇒ Integer
The number of node groups (shards) that results from the modification of the shard configuration.
Instance Attribute Details
#apply_immediately ⇒ Boolean
Indicates that the shard reconfiguration process begins immediately. At present, the only permitted value for this parameter is true.
3292 3293 3294 3295 3296 3297 3298 3299 3300 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3292 class DecreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :global_node_groups_to_remove, :global_node_groups_to_retain, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#global_node_groups_to_remove ⇒ Array<String>
If the value of NodeGroupCount is less than the current number of node groups (shards), then either NodeGroupsToRemove or NodeGroupsToRetain is required. GlobalNodeGroupsToRemove is a list of NodeGroupIds to remove from the cluster. ElastiCache for Redis will attempt to remove all node groups listed by GlobalNodeGroupsToRemove from the cluster.
3292 3293 3294 3295 3296 3297 3298 3299 3300 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3292 class DecreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :global_node_groups_to_remove, :global_node_groups_to_retain, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#global_node_groups_to_retain ⇒ Array<String>
If the value of NodeGroupCount is less than the current number of node groups (shards), then either NodeGroupsToRemove or NodeGroupsToRetain is required. GlobalNodeGroupsToRetain is a list of NodeGroupIds to retain from the cluster. ElastiCache for Redis will attempt to retain all node groups listed by GlobalNodeGroupsToRetain from the cluster.
3292 3293 3294 3295 3296 3297 3298 3299 3300 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3292 class DecreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :global_node_groups_to_remove, :global_node_groups_to_retain, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#global_replication_group_id ⇒ String
The name of the Global datastore
3292 3293 3294 3295 3296 3297 3298 3299 3300 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3292 class DecreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :global_node_groups_to_remove, :global_node_groups_to_retain, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#node_group_count ⇒ Integer
The number of node groups (shards) that results from the modification of the shard configuration
3292 3293 3294 3295 3296 3297 3298 3299 3300 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3292 class DecreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :global_node_groups_to_remove, :global_node_groups_to_retain, :apply_immediately) SENSITIVE = [] include Aws::Structure end |