Class: Aws::ElastiCache::Types::DeleteCacheClusterResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DeleteCacheClusterResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_cluster ⇒ Types::CacheCluster
Contains all of the attributes of a specific cluster.
Instance Attribute Details
#cache_cluster ⇒ Types::CacheCluster
Contains all of the attributes of a specific cluster.
3405 3406 3407 3408 3409 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3405 class DeleteCacheClusterResult < Struct.new( :cache_cluster) SENSITIVE = [] include Aws::Structure end |