Class: Aws::ElastiCache::Types::DeleteCacheParameterGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DeleteCacheParameterGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Note:
When making an API call, you may pass DeleteCacheParameterGroupMessage data as a hash:
{
cache_parameter_group_name: "String", # required
}
Represents the input of a DeleteCacheParameterGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to delete.
Instance Attribute Details
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to delete.
<note markdown=“1”> The specified cache security group must not be associated with any clusters.
</note>
3481 3482 3483 3484 3485 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3481 class DeleteCacheParameterGroupMessage < Struct.new( :cache_parameter_group_name) SENSITIVE = [] include Aws::Structure end |