Class: Aws::ElastiCache::Types::DeleteCacheSecurityGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DeleteCacheSecurityGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Note:
When making an API call, you may pass DeleteCacheSecurityGroupMessage data as a hash:
{
cache_security_group_name: "String", # required
}
Represents the input of a DeleteCacheSecurityGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_security_group_name ⇒ String
The name of the cache security group to delete.
Instance Attribute Details
#cache_security_group_name ⇒ String
The name of the cache security group to delete.
<note markdown=“1”> You cannot delete the default security group.
</note>
3506 3507 3508 3509 3510 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3506 class DeleteCacheSecurityGroupMessage < Struct.new( :cache_security_group_name) SENSITIVE = [] include Aws::Structure end |