Class: Aws::ElastiCache::Types::DescribeCacheClustersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeCacheClustersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass DescribeCacheClustersMessage data as a hash:
{
cache_cluster_id: "String",
max_records: 1,
marker: "String",
show_cache_node_info: false,
show_cache_clusters_not_in_replication_groups: false,
}
Represents the input of a DescribeCacheClusters operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_cluster_id ⇒ String
The user-supplied cluster identifier.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#show_cache_clusters_not_in_replication_groups ⇒ Boolean
An optional flag that can be included in the
DescribeCacheClusterrequest to show only nodes (API/CLI: clusters) that are not members of a replication group. -
#show_cache_node_info ⇒ Boolean
An optional flag that can be included in the
DescribeCacheClusterrequest to retrieve information about the individual cache nodes.
Instance Attribute Details
#cache_cluster_id ⇒ String
The user-supplied cluster identifier. If this parameter is specified, only information about that specific cluster is returned. This parameter isn’t case sensitive.
3758 3759 3760 3761 3762 3763 3764 3765 3766 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3758 class DescribeCacheClustersMessage < Struct.new( :cache_cluster_id, :max_records, :marker, :show_cache_node_info, :show_cache_clusters_not_in_replication_groups) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
3758 3759 3760 3761 3762 3763 3764 3765 3766 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3758 class DescribeCacheClustersMessage < Struct.new( :cache_cluster_id, :max_records, :marker, :show_cache_node_info, :show_cache_clusters_not_in_replication_groups) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: minimum 20; maximum 100.
3758 3759 3760 3761 3762 3763 3764 3765 3766 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3758 class DescribeCacheClustersMessage < Struct.new( :cache_cluster_id, :max_records, :marker, :show_cache_node_info, :show_cache_clusters_not_in_replication_groups) SENSITIVE = [] include Aws::Structure end |
#show_cache_clusters_not_in_replication_groups ⇒ Boolean
An optional flag that can be included in the DescribeCacheCluster request to show only nodes (API/CLI: clusters) that are not members of a replication group. In practice, this mean Memcached and single node Redis clusters.
3758 3759 3760 3761 3762 3763 3764 3765 3766 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3758 class DescribeCacheClustersMessage < Struct.new( :cache_cluster_id, :max_records, :marker, :show_cache_node_info, :show_cache_clusters_not_in_replication_groups) SENSITIVE = [] include Aws::Structure end |
#show_cache_node_info ⇒ Boolean
An optional flag that can be included in the DescribeCacheCluster request to retrieve information about the individual cache nodes.
3758 3759 3760 3761 3762 3763 3764 3765 3766 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3758 class DescribeCacheClustersMessage < Struct.new( :cache_cluster_id, :max_records, :marker, :show_cache_node_info, :show_cache_clusters_not_in_replication_groups) SENSITIVE = [] include Aws::Structure end |