Class: Aws::ElastiCache::Types::DescribeCacheEngineVersionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeCacheEngineVersionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Represents the input of a ‘DescribeCacheEngineVersions` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_parameter_group_family ⇒ String
The name of a specific cache parameter group family to return details for.
-
#default_only ⇒ Boolean
If ‘true`, specifies that only the default version of the specified engine or engine and major version combination is to be returned.
-
#engine ⇒ String
The cache engine to return.
-
#engine_version ⇒ String
The cache engine version to return.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#cache_parameter_group_family ⇒ String
The name of a specific cache parameter group family to return details for.
Valid values are: ‘memcached1.4` | `memcached1.5` | `memcached1.6` | `redis2.6` | `redis2.8` | `redis3.2` | `redis4.0` | `redis5.0` | `redis6.x` | `redis6.2` | `redis7` | `valkey7`
Constraints:
-
Must be 1 to 255 alphanumeric characters
-
First character must be a letter
-
Cannot end with a hyphen or contain two consecutive hyphens
3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3750 class DescribeCacheEngineVersionsMessage < Struct.new( :engine, :engine_version, :cache_parameter_group_family, :max_records, :marker, :default_only) SENSITIVE = [] include Aws::Structure end |
#default_only ⇒ Boolean
If ‘true`, specifies that only the default version of the specified engine or engine and major version combination is to be returned.
3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3750 class DescribeCacheEngineVersionsMessage < Struct.new( :engine, :engine_version, :cache_parameter_group_family, :max_records, :marker, :default_only) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The cache engine to return. Valid values: ‘memcached` | `redis`
3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3750 class DescribeCacheEngineVersionsMessage < Struct.new( :engine, :engine_version, :cache_parameter_group_family, :max_records, :marker, :default_only) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The cache engine version to return.
Example: ‘1.4.14`
3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3750 class DescribeCacheEngineVersionsMessage < Struct.new( :engine, :engine_version, :cache_parameter_group_family, :max_records, :marker, :default_only) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3750 class DescribeCacheEngineVersionsMessage < Struct.new( :engine, :engine_version, :cache_parameter_group_family, :max_records, :marker, :default_only) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: minimum 20; maximum 100.
3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3750 class DescribeCacheEngineVersionsMessage < Struct.new( :engine, :engine_version, :cache_parameter_group_family, :max_records, :marker, :default_only) SENSITIVE = [] include Aws::Structure end |