Class: Aws::ElastiCache::Types::DescribeCacheParametersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeCacheParametersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Represents the input of a ‘DescribeCacheParameters` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_parameter_group_name ⇒ String
The name of a specific cache parameter group to return details for.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source ⇒ String
The parameter types to return.
Instance Attribute Details
#cache_parameter_group_name ⇒ String
The name of a specific cache parameter group to return details for.
3827 3828 3829 3830 3831 3832 3833 3834 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3827 class DescribeCacheParametersMessage < Struct.new( :cache_parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
3827 3828 3829 3830 3831 3832 3833 3834 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3827 class DescribeCacheParametersMessage < Struct.new( :cache_parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: minimum 20; maximum 100.
3827 3828 3829 3830 3831 3832 3833 3834 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3827 class DescribeCacheParametersMessage < Struct.new( :cache_parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The parameter types to return.
Valid values: ‘user` | `system` | `engine-default`
3827 3828 3829 3830 3831 3832 3833 3834 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3827 class DescribeCacheParametersMessage < Struct.new( :cache_parameter_group_name, :source, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |