Class: Aws::ElastiCache::Types::DescribeEventsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeEventsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Represents the input of a DescribeEvents operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#duration ⇒ Integer
The number of minutes worth of events to retrieve.
-
#end_time ⇒ Time
The end of the time interval for which to retrieve events, specified in ISO 8601 format.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source_identifier ⇒ String
The identifier of the event source for which events are returned.
-
#source_type ⇒ String
The event source to retrieve events for.
-
#start_time ⇒ Time
The beginning of the time interval to retrieve events for, specified in ISO 8601 format.
Instance Attribute Details
#duration ⇒ Integer
The number of minutes worth of events to retrieve.
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4015 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The end of the time interval for which to retrieve events, specified in ISO 8601 format.
Example: 2017-03-30T07:03:49.555Z
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4015 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker
for pagination of results from this operation. If this parameter is
specified, the response includes only records beyond the marker, up
to the value specified by MaxRecords.
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4015 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a marker is
included in the response so that the remaining results can be
retrieved.
Default: 100
Constraints: minimum 20; maximum 100.
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4015 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source_identifier ⇒ String
The identifier of the event source for which events are returned. If not specified, all sources are included in the response.
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4015 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The event source to retrieve events for. If no value is specified, all events are returned.
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4015 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The beginning of the time interval to retrieve events for, specified in ISO 8601 format.
Example: 2017-03-30T07:03:49.555Z
4015 4016 4017 4018 4019 4020 4021 4022 4023 4024 4025 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4015 class DescribeEventsMessage < Struct.new( :source_identifier, :source_type, :start_time, :end_time, :duration, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |