Class: Aws::ElastiCache::Types::DescribeGlobalReplicationGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeGlobalReplicationGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_replication_group_id ⇒ String
The name of the Global datastore.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#show_member_info ⇒ Boolean
Returns the list of members that comprise the Global datastore.
Instance Attribute Details
#global_replication_group_id ⇒ String
The name of the Global datastore
4051 4052 4053 4054 4055 4056 4057 4058 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4051 class DescribeGlobalReplicationGroupsMessage < Struct.new( :global_replication_group_id, :max_records, :marker, :show_member_info) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
4051 4052 4053 4054 4055 4056 4057 4058 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4051 class DescribeGlobalReplicationGroupsMessage < Struct.new( :global_replication_group_id, :max_records, :marker, :show_member_info) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.
4051 4052 4053 4054 4055 4056 4057 4058 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4051 class DescribeGlobalReplicationGroupsMessage < Struct.new( :global_replication_group_id, :max_records, :marker, :show_member_info) SENSITIVE = [] include Aws::Structure end |
#show_member_info ⇒ Boolean
Returns the list of members that comprise the Global datastore.
4051 4052 4053 4054 4055 4056 4057 4058 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4051 class DescribeGlobalReplicationGroupsMessage < Struct.new( :global_replication_group_id, :max_records, :marker, :show_member_info) SENSITIVE = [] include Aws::Structure end |