Class: Aws::ElastiCache::Types::DescribeReplicationGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeReplicationGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Represents the input of a ‘DescribeReplicationGroups` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#replication_group_id ⇒ String
The identifier for the replication group to be described.
Instance Attribute Details
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4111 class DescribeReplicationGroupsMessage < Struct.new( :replication_group_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: minimum 20; maximum 100.
4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4111 class DescribeReplicationGroupsMessage < Struct.new( :replication_group_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The identifier for the replication group to be described. This parameter is not case sensitive.
If you do not specify this parameter, information about all replication groups is returned.
4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4111 class DescribeReplicationGroupsMessage < Struct.new( :replication_group_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |