Class: Aws::ElastiCache::Types::DescribeServerlessCachesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeServerlessCachesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of records in the response.
-
#next_token ⇒ String
An optional marker returned from a prior request to support pagination of results from this operation.
-
#serverless_cache_name ⇒ String
The identifier for the serverless cache.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of records in the response. If more records exist than the specified max-records value, the next token is included in the response so that remaining results can be retrieved. The default is 50.
4575 4576 4577 4578 4579 4580 4581 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4575 class DescribeServerlessCachesRequest < Struct.new( :serverless_cache_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An optional marker returned from a prior request to support pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxResults.
4575 4576 4577 4578 4579 4580 4581 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4575 class DescribeServerlessCachesRequest < Struct.new( :serverless_cache_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#serverless_cache_name ⇒ String
The identifier for the serverless cache. If this parameter is specified, only information about that specific serverless cache is returned. Default: NULL
4575 4576 4577 4578 4579 4580 4581 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4575 class DescribeServerlessCachesRequest < Struct.new( :serverless_cache_name, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |