Class: Aws::ElastiCache::Types::DescribeServerlessCachesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeServerlessCachesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An optional marker returned from a prior request to support pagination of results from this operation.
-
#serverless_caches ⇒ Array<Types::ServerlessCache>
The serverless caches associated with a given description request.
Instance Attribute Details
#next_token ⇒ String
An optional marker returned from a prior request to support pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxResults.
4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4596 class DescribeServerlessCachesResponse < Struct.new( :next_token, :serverless_caches) SENSITIVE = [] include Aws::Structure end |
#serverless_caches ⇒ Array<Types::ServerlessCache>
The serverless caches associated with a given description request.
4596 4597 4598 4599 4600 4601 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4596 class DescribeServerlessCachesResponse < Struct.new( :next_token, :serverless_caches) SENSITIVE = [] include Aws::Structure end |