Class: Aws::ElastiCache::Types::DescribeServiceUpdatesMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.

Returns:

  • (String)


4624
4625
4626
4627
4628
4629
4630
4631
# File 'lib/aws-sdk-elasticache/types.rb', line 4624

class DescribeServiceUpdatesMessage < Struct.new(
  :service_update_name,
  :service_update_status,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response

Returns:

  • (Integer)


4624
4625
4626
4627
4628
4629
4630
4631
# File 'lib/aws-sdk-elasticache/types.rb', line 4624

class DescribeServiceUpdatesMessage < Struct.new(
  :service_update_name,
  :service_update_status,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_nameString

The unique ID of the service update

Returns:

  • (String)


4624
4625
4626
4627
4628
4629
4630
4631
# File 'lib/aws-sdk-elasticache/types.rb', line 4624

class DescribeServiceUpdatesMessage < Struct.new(
  :service_update_name,
  :service_update_status,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_statusArray<String>

The status of the service update

Returns:

  • (Array<String>)


4624
4625
4626
4627
4628
4629
4630
4631
# File 'lib/aws-sdk-elasticache/types.rb', line 4624

class DescribeServiceUpdatesMessage < Struct.new(
  :service_update_name,
  :service_update_status,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end