Class: Aws::ElastiCache::Types::DescribeSnapshotsListMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Represents the output of a DescribeSnapshots operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


4649
4650
4651
4652
4653
4654
# File 'lib/aws-sdk-elasticache/types.rb', line 4649

class DescribeSnapshotsListMessage < Struct.new(
  :marker,
  :snapshots)
  SENSITIVE = []
  include Aws::Structure
end

#snapshotsArray<Types::Snapshot>

A list of snapshots. Each item in the list contains detailed information about one snapshot.

Returns:



4649
4650
4651
4652
4653
4654
# File 'lib/aws-sdk-elasticache/types.rb', line 4649

class DescribeSnapshotsListMessage < Struct.new(
  :marker,
  :snapshots)
  SENSITIVE = []
  include Aws::Structure
end