Class: Aws::ElastiCache::Types::DescribeUpdateActionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeUpdateActionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass DescribeUpdateActionsMessage data as a hash:
{
service_update_name: "String",
replication_group_ids: ["String"],
cache_cluster_ids: ["String"],
engine: "String",
service_update_status: ["available"], # accepts available, cancelled, expired
service_update_time_range: {
start_time: Time.now,
end_time: Time.now,
},
update_action_status: ["not-applied"], # accepts not-applied, waiting-to-start, in-progress, stopping, stopped, complete, scheduling, scheduled, not-applicable
show_node_level_update_status: false,
max_records: 1,
marker: "String",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_cluster_ids ⇒ Array<String>
The cache cluster IDs.
-
#engine ⇒ String
The Elasticache engine to which the update applies.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#replication_group_ids ⇒ Array<String>
The replication group IDs.
-
#service_update_name ⇒ String
The unique ID of the service update.
-
#service_update_status ⇒ Array<String>
The status of the service update.
-
#service_update_time_range ⇒ Types::TimeRangeFilter
The range of time specified to search for service updates that are in available status.
-
#show_node_level_update_status ⇒ Boolean
Dictates whether to include node level update status in the response.
-
#update_action_status ⇒ Array<String>
The status of the update action.
Instance Attribute Details
#cache_cluster_ids ⇒ Array<String>
The cache cluster IDs
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The Elasticache engine to which the update applies. Either Redis or Memcached
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#replication_group_ids ⇒ Array<String>
The replication group IDs
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#service_update_name ⇒ String
The unique ID of the service update
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#service_update_status ⇒ Array<String>
The status of the service update
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#service_update_time_range ⇒ Types::TimeRangeFilter
The range of time specified to search for service updates that are in available status
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#show_node_level_update_status ⇒ Boolean
Dictates whether to include node level update status in the response
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#update_action_status ⇒ Array<String>
The status of the update action.
4857 4858 4859 4860 4861 4862 4863 4864 4865 4866 4867 4868 4869 4870 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4857 class DescribeUpdateActionsMessage < Struct.new( :service_update_name, :replication_group_ids, :cache_cluster_ids, :engine, :service_update_status, :service_update_time_range, :update_action_status, :show_node_level_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |