Class: Aws::ElastiCache::Types::DescribeUsersMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#engineString

The engine.

Returns:

  • (String)


4856
4857
4858
4859
4860
4861
4862
4863
4864
# File 'lib/aws-sdk-elasticache/types.rb', line 4856

class DescribeUsersMessage < Struct.new(
  :engine,
  :user_id,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Filter to determine the list of User IDs to return.

Returns:



4856
4857
4858
4859
4860
4861
4862
4863
4864
# File 'lib/aws-sdk-elasticache/types.rb', line 4856

class DescribeUsersMessage < Struct.new(
  :engine,
  :user_id,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. &gt;

Returns:

  • (String)


4856
4857
4858
4859
4860
4861
4862
4863
4864
# File 'lib/aws-sdk-elasticache/types.rb', line 4856

class DescribeUsersMessage < Struct.new(
  :engine,
  :user_id,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


4856
4857
4858
4859
4860
4861
4862
4863
4864
# File 'lib/aws-sdk-elasticache/types.rb', line 4856

class DescribeUsersMessage < Struct.new(
  :engine,
  :user_id,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#user_idString

The ID of the user.

Returns:

  • (String)


4856
4857
4858
4859
4860
4861
4862
4863
4864
# File 'lib/aws-sdk-elasticache/types.rb', line 4856

class DescribeUsersMessage < Struct.new(
  :engine,
  :user_id,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end