Class: Aws::ElastiCache::Types::DisassociateGlobalReplicationGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Note:

When making an API call, you may pass DisassociateGlobalReplicationGroupMessage data as a hash:

{
  global_replication_group_id: "String", # required
  replication_group_id: "String", # required
  replication_group_region: "String", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#global_replication_group_idString

The name of the Global datastore

Returns:

  • (String)


5060
5061
5062
5063
5064
5065
5066
# File 'lib/aws-sdk-elasticache/types.rb', line 5060

class DisassociateGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :replication_group_id,
  :replication_group_region)
  SENSITIVE = []
  include Aws::Structure
end

#replication_group_idString

The name of the secondary cluster you wish to remove from the Global datastore

Returns:

  • (String)


5060
5061
5062
5063
5064
5065
5066
# File 'lib/aws-sdk-elasticache/types.rb', line 5060

class DisassociateGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :replication_group_id,
  :replication_group_region)
  SENSITIVE = []
  include Aws::Structure
end

#replication_group_regionString

The Amazon region of secondary cluster you wish to remove from the Global datastore

Returns:

  • (String)


5060
5061
5062
5063
5064
5065
5066
# File 'lib/aws-sdk-elasticache/types.rb', line 5060

class DisassociateGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :replication_group_id,
  :replication_group_region)
  SENSITIVE = []
  include Aws::Structure
end