Class: Aws::ElastiCache::Types::Event
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::Event
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Represents a single occurrence of something interesting within the system. Some examples of events are creating a cluster, adding or removing a cache node, or rebooting a node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#date ⇒ Time
The date and time when the event occurred.
-
#message ⇒ String
The text of the event.
-
#source_identifier ⇒ String
The identifier for the source of the event.
-
#source_type ⇒ String
Specifies the origin of this event - a cluster, a parameter group, a security group, etc.
Instance Attribute Details
#date ⇒ Time
The date and time when the event occurred.
5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5086 class Event < Struct.new( :source_identifier, :source_type, :message, :date) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The text of the event.
5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5086 class Event < Struct.new( :source_identifier, :source_type, :message, :date) SENSITIVE = [] include Aws::Structure end |
#source_identifier ⇒ String
The identifier for the source of the event. For example, if the event occurred at the cluster level, the identifier would be the name of the cluster.
5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5086 class Event < Struct.new( :source_identifier, :source_type, :message, :date) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
Specifies the origin of this event - a cluster, a parameter group, a security group, etc.
5086 5087 5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5086 class Event < Struct.new( :source_identifier, :source_type, :message, :date) SENSITIVE = [] include Aws::Structure end |