Class: Aws::ElastiCache::Types::EventsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Represents the output of a DescribeEvents operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#eventsArray<Types::Event>

A list of events. Each element in the list contains detailed information about one event.

Returns:



5224
5225
5226
5227
5228
5229
# File 'lib/aws-sdk-elasticache/types.rb', line 5224

class EventsMessage < Struct.new(
  :marker,
  :events)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Provides an identifier to allow retrieval of paginated results.

Returns:

  • (String)


5224
5225
5226
5227
5228
5229
# File 'lib/aws-sdk-elasticache/types.rb', line 5224

class EventsMessage < Struct.new(
  :marker,
  :events)
  SENSITIVE = []
  include Aws::Structure
end