Class: Aws::ElastiCache::Types::ExportServerlessCacheSnapshotRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3_bucket_nameString

Name of the Amazon S3 bucket to export the snapshot to. The Amazon S3 bucket must also be in same region as the snapshot. Available for Valkey and Redis OSS only.

Returns:

  • (String)


5118
5119
5120
5121
5122
5123
# File 'lib/aws-sdk-elasticache/types.rb', line 5118

class ExportServerlessCacheSnapshotRequest < Struct.new(
  :serverless_cache_snapshot_name,
  :s3_bucket_name)
  SENSITIVE = []
  include Aws::Structure
end

#serverless_cache_snapshot_nameString

The identifier of the serverless cache snapshot to be exported to S3. Available for Valkey and Redis OSS only.

Returns:

  • (String)


5118
5119
5120
5121
5122
5123
# File 'lib/aws-sdk-elasticache/types.rb', line 5118

class ExportServerlessCacheSnapshotRequest < Struct.new(
  :serverless_cache_snapshot_name,
  :s3_bucket_name)
  SENSITIVE = []
  include Aws::Structure
end