Class: Aws::ElastiCache::Types::GlobalReplicationGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Consists of a primary cluster that accepts writes and an associated secondary cluster that resides in a different Amazon region. The secondary cluster accepts only reads. The primary cluster automatically replicates updates to the secondary cluster.

  • The GlobalReplicationGroupIdSuffix represents the name of the Global datastore, which is what you use to associate a secondary cluster.

^

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN (Amazon Resource Name) of the global replication group.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#at_rest_encryption_enabledBoolean

A flag that enables encryption at rest when set to true.

You cannot modify the value of AtRestEncryptionEnabled after the replication group is created. To enable encryption at rest on a replication group you must set AtRestEncryptionEnabled to true when you create the replication group.

Required: Only available when creating a replication group in an Amazon VPC using Redis OSS version 3.2.6, 4.x or later.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#auth_token_enabledBoolean

A flag that enables using an AuthToken (password) when issuing Valkey or Redis OSS commands.

Default: false



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#cache_node_typeString

The cache node type of the Global datastore



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_enabledBoolean

A flag that indicates whether the Global datastore is cluster enabled.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The ElastiCache engine. For Valkey or Redis OSS only.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The ElastiCache engine version.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#global_node_groupsArray<Types::GlobalNodeGroup>

Indicates the slot configuration and global identifier for each slice group.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#global_replication_group_descriptionString

The optional description of the Global datastore



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#global_replication_group_idString

The name of the Global datastore



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#membersArray<Types::GlobalReplicationGroupMember>

The replication groups that comprise the Global datastore.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the Global datastore



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end

#transit_encryption_enabledBoolean

A flag that enables in-transit encryption when set to true.

Required: Only available when creating a replication group in an Amazon VPC using Redis OSS version 3.2.6, 4.x or later.



5289
5290
5291
5292
5293
5294
5295
5296
5297
5298
5299
5300
5301
5302
5303
5304
5305
# File 'lib/aws-sdk-elasticache/types.rb', line 5289

class GlobalReplicationGroup < Struct.new(
  :global_replication_group_id,
  :global_replication_group_description,
  :status,
  :cache_node_type,
  :engine,
  :engine_version,
  :members,
  :cluster_enabled,
  :global_node_groups,
  :auth_token_enabled,
  :transit_encryption_enabled,
  :at_rest_encryption_enabled,
  :arn)
  SENSITIVE = []
  include Aws::Structure
end