Class: Aws::ElastiCache::Types::IncreaseNodeGroupsInGlobalReplicationGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::IncreaseNodeGroupsInGlobalReplicationGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
Indicates that the process begins immediately.
-
#global_replication_group_id ⇒ String
The name of the Global datastore.
-
#node_group_count ⇒ Integer
Total number of node groups you want.
-
#regional_configurations ⇒ Array<Types::RegionalConfiguration>
Describes the replication group IDs, the Amazon regions where they are stored and the shard configuration for each that comprise the Global datastore.
Instance Attribute Details
#apply_immediately ⇒ Boolean
Indicates that the process begins immediately. At present, the only permitted value for this parameter is true.
5421 5422 5423 5424 5425 5426 5427 5428 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5421 class IncreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :regional_configurations, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#global_replication_group_id ⇒ String
The name of the Global datastore
5421 5422 5423 5424 5425 5426 5427 5428 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5421 class IncreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :regional_configurations, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#node_group_count ⇒ Integer
Total number of node groups you want
5421 5422 5423 5424 5425 5426 5427 5428 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5421 class IncreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :regional_configurations, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#regional_configurations ⇒ Array<Types::RegionalConfiguration>
Describes the replication group IDs, the Amazon regions where they are stored and the shard configuration for each that comprise the Global datastore
5421 5422 5423 5424 5425 5426 5427 5428 |
# File 'lib/aws-sdk-elasticache/types.rb', line 5421 class IncreaseNodeGroupsInGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :node_group_count, :regional_configurations, :apply_immediately) SENSITIVE = [] include Aws::Structure end |