Class: Aws::ElastiCache::Types::ModifyCacheClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ModifyCacheClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass ModifyCacheClusterMessage data as a hash:
{
cache_cluster_id: "String", # required
num_cache_nodes: 1,
cache_node_ids_to_remove: ["String"],
az_mode: "single-az", # accepts single-az, cross-az
new_availability_zones: ["String"],
cache_security_group_names: ["String"],
security_group_ids: ["String"],
preferred_maintenance_window: "String",
notification_topic_arn: "String",
cache_parameter_group_name: "String",
notification_topic_status: "String",
apply_immediately: false,
engine_version: "String",
auto_minor_version_upgrade: false,
snapshot_retention_limit: 1,
snapshot_window: "String",
cache_node_type: "String",
auth_token: "String",
auth_token_update_strategy: "SET", # accepts SET, ROTATE, DELETE
log_delivery_configurations: [
{
log_type: "slow-log", # accepts slow-log, engine-log
destination_type: "cloudwatch-logs", # accepts cloudwatch-logs, kinesis-firehose
destination_details: {
cloud_watch_logs_details: {
log_group: "String",
},
kinesis_firehose_details: {
delivery_stream: "String",
},
},
log_format: "text", # accepts text, json
enabled: false,
},
],
ip_discovery: "ipv4", # accepts ipv4, ipv6
}
Represents the input of a ModifyCacheCluster operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
If
true, this parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible, regardless of thePreferredMaintenanceWindowsetting for the cluster. -
#auth_token ⇒ String
Reserved parameter.
-
#auth_token_update_strategy ⇒ String
Specifies the strategy to use to update the AUTH token.
-
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign.
-
#az_mode ⇒ String
Specifies whether the new nodes in this Memcached cluster are all created in a single Availability Zone or created across multiple Availability Zones.
-
#cache_cluster_id ⇒ String
The cluster identifier.
-
#cache_node_ids_to_remove ⇒ Array<String>
A list of cache node IDs to be removed.
-
#cache_node_type ⇒ String
A valid cache node type that you want to scale this cluster up to.
-
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to apply to this cluster.
-
#cache_security_group_names ⇒ Array<String>
A list of cache security group names to authorize on this cluster.
-
#engine_version ⇒ String
The upgraded version of the cache engine to be run on the cache nodes.
-
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either
ipv4|ipv6. -
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfigurationRequest>
Specifies the destination, format and type of the logs.
-
#new_availability_zones ⇒ Array<String>
<note markdown=“1”> This option is only supported on Memcached clusters.
-
#notification_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications are sent.
-
#notification_topic_status ⇒ String
The status of the Amazon SNS notification topic.
-
#num_cache_nodes ⇒ Integer
The number of cache nodes that the cluster should have.
-
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed.
-
#security_group_ids ⇒ Array<String>
Specifies the VPC Security Groups associated with the cluster.
-
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic cluster snapshots before deleting them.
-
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your cluster.
Instance Attribute Details
#apply_immediately ⇒ Boolean
If true, this parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible, regardless of the PreferredMaintenanceWindow setting for the cluster.
If false, changes to the cluster are applied on the next maintenance reboot, or the next failure reboot, whichever occurs first.
If you perform a ModifyCacheCluster before a pending modification is applied, the pending modification is replaced by the newer modification.
Valid values: true | false
Default: false
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auth_token ⇒ String
Reserved parameter. The password used to access a password protected server. This parameter must be specified with the auth-token-update parameter. Password constraints:
-
Must be only printable ASCII characters
-
Must be at least 16 characters and no more than 128 characters in length
-
Cannot contain any of the following characters: ‘/’, ‘“’, or ‘@’, ‘%’
For more information, see AUTH password at [AUTH].
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auth_token_update_strategy ⇒ String
Specifies the strategy to use to update the AUTH token. This parameter must be specified with the auth-token parameter. Possible values:
-
Rotate
-
Set
For more information, see [Authenticating Users with Redis AUTH]
[1]: docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign. This parameter is disabled for previous versions.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#az_mode ⇒ String
Specifies whether the new nodes in this Memcached cluster are all created in a single Availability Zone or created across multiple Availability Zones.
Valid values: single-az | cross-az.
This option is only supported for Memcached clusters.
<note markdown=“1”> You cannot specify single-az if the Memcached cluster already has cache nodes in different Availability Zones. If cross-az is specified, existing Memcached nodes remain in their current Availability Zone.
Only newly created nodes are located in different Availability
Zones.
</note>
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_cluster_id ⇒ String
The cluster identifier. This value is stored as a lowercase string.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_node_ids_to_remove ⇒ Array<String>
A list of cache node IDs to be removed. A node ID is a numeric identifier (0001, 0002, etc.). This parameter is only valid when NumCacheNodes is less than the existing number of cache nodes. The number of cache node IDs supplied in this parameter must match the difference between the existing number of cache nodes in the cluster or pending cache nodes, whichever is greater, and the value of NumCacheNodes in the request.
For example: If you have 3 active cache nodes, 7 pending cache nodes, and the number of cache nodes in this ModifyCacheCluster call is 5, you must list 2 (7 - 5) cache node IDs to remove.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
A valid cache node type that you want to scale this cluster up to.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to apply to this cluster. This change is asynchronously applied as soon as possible for parameters when the ApplyImmediately parameter is specified as true for this request.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_security_group_names ⇒ Array<String>
A list of cache security group names to authorize on this cluster. This change is asynchronously applied as soon as possible.
You can use this parameter only with clusters that are created outside of an Amazon Virtual Private Cloud (Amazon VPC).
Constraints: Must contain no more than 255 alphanumeric characters. Must not be “Default”.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The upgraded version of the cache engine to be run on the cache nodes.
Important: You can upgrade to a newer engine version (see [Selecting a Cache Engine and Version]), but you cannot downgrade to an earlier engine version. If you want to use an earlier engine version, you must delete the existing cluster and create it anew with the earlier engine version.
[1]: docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either ipv4 | ipv6. IPv6 is supported for workloads using Redis engine version 6.2 onward or Memcached engine version 1.6.6 on all instances built on the [Nitro system].
[1]: aws.amazon.com/ec2/nitro/
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfigurationRequest>
Specifies the destination, format and type of the logs.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#new_availability_zones ⇒ Array<String>
<note markdown=“1”> This option is only supported on Memcached clusters.
</note>
The list of Availability Zones where the new Memcached cache nodes are created.
This parameter is only valid when NumCacheNodes in the request is greater than the sum of the number of active cache nodes and the number of cache nodes pending creation (which may be zero). The number of Availability Zones supplied in this list must match the cache nodes being added in this request.
Scenarios:
-
**Scenario 1:** You have 3 active nodes and wish to add 2 nodes. Specify ‘NumCacheNodes=5` (3 + 2) and optionally specify two Availability Zones for the two new nodes.
-
**Scenario 2:** You have 3 active nodes and 2 nodes pending creation (from the scenario 1 call) and want to add 1 more node. Specify ‘NumCacheNodes=6` ((3 + 2) + 1) and optionally specify an Availability Zone for the new node.
-
**Scenario 3:** You want to cancel all pending operations. Specify ‘NumCacheNodes=3` to cancel all pending operations.
The Availability Zone placement of nodes pending creation cannot be modified. If you wish to cancel any nodes pending creation, add 0 nodes by setting NumCacheNodes to the number of current nodes.
If cross-az is specified, existing Memcached nodes remain in their current Availability Zone. Only newly created nodes can be located in different Availability Zones. For guidance on how to move existing Memcached nodes to different Availability Zones, see the **Availability Zone Considerations** section of [Cache Node Considerations for Memcached].
**Impact of new add/remove requests upon pending requests**
-
Scenario-1
-
Pending Action: Delete
-
New Request: Delete
-
Result: The new delete, pending or immediate, replaces the pending delete.
-
-
Scenario-2
-
Pending Action: Delete
-
New Request: Create
-
Result: The new create, pending or immediate, replaces the pending delete.
-
-
Scenario-3
-
Pending Action: Create
-
New Request: Delete
-
Result: The new delete, pending or immediate, replaces the pending create.
-
-
Scenario-4
-
Pending Action: Create
-
New Request: Create
-
Result: The new create is added to the pending create.
Important: If the new create request is **Apply Immediately
-
Yes**, all creates are performed immediately. If the new
create request is **Apply Immediately - No**, all creates are pending.
-
-
[1]: docs.aws.amazon.com/AmazonElastiCache/latest/mem-ug/CacheNodes.SupportedTypes.html
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#notification_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications are sent.
<note markdown=“1”> The Amazon SNS topic owner must be same as the cluster owner.
</note>
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#notification_topic_status ⇒ String
The status of the Amazon SNS notification topic. Notifications are sent only if the status is active.
Valid values: active | inactive
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#num_cache_nodes ⇒ Integer
The number of cache nodes that the cluster should have. If the value for NumCacheNodes is greater than the sum of the number of current cache nodes and the number of cache nodes pending creation (which may be zero), more nodes are added. If the value is less than the number of existing cache nodes, nodes are removed. If the value is equal to the number of current cache nodes, any pending add or remove requests are canceled.
If you are removing cache nodes, you must use the CacheNodeIdsToRemove parameter to provide the IDs of the specific cache nodes to remove.
For clusters running Redis, this value must be 1. For clusters running Memcached, this value must be between 1 and 40.
<note markdown=“1”> Adding or removing Memcached cache nodes can be applied immediately or as a pending operation (see ApplyImmediately).
A pending operation to modify the number of cache nodes in a cluster
during its maintenance window, whether by adding or removing nodes in accordance with the scale out architecture, is not queued. The customer’s latest request to add or remove nodes to the cluster overrides any previous pending operations to modify the number of cache nodes in the cluster. For example, a request to remove 2 nodes would override a previous pending operation to remove 3 nodes. Similarly, a request to add 2 nodes would override a previous pending operation to remove 3 nodes and vice versa. As Memcached cache nodes may now be provisioned in different Availability Zones with flexible cache node placement, a request to add nodes does not automatically override a previous pending operation to add nodes. The customer can modify the previous pending operation to add more nodes or explicitly cancel the pending request and retry the new request. To cancel pending operations to modify the number of cache nodes in a cluster, use the ModifyCacheCluster request and set NumCacheNodes equal to the number of cache nodes currently in the cluster.
</note>
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.
Valid values for ddd are:
-
sun -
mon -
tue -
wed -
thu -
fri -
sat
Example: sun:23:00-mon:01:30
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
Specifies the VPC Security Groups associated with the cluster.
This parameter can be used only with clusters that are created in an Amazon Virtual Private Cloud (Amazon VPC).
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic cluster snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.
<note markdown=“1”> If the value of SnapshotRetentionLimit is set to zero (0), backups are turned off.
</note>
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your cluster.
6343 6344 6345 6346 6347 6348 6349 6350 6351 6352 6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 6366 6367 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6343 class ModifyCacheClusterMessage < Struct.new( :cache_cluster_id, :num_cache_nodes, :cache_node_ids_to_remove, :az_mode, :new_availability_zones, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |