Class: Aws::ElastiCache::Types::ModifyGlobalReplicationGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ModifyGlobalReplicationGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
This parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible.
-
#automatic_failover_enabled ⇒ Boolean
Determines whether a read replica is automatically promoted to read/write primary if the existing primary encounters a failure.
-
#cache_node_type ⇒ String
A valid cache node type that you want to scale this Global datastore to.
-
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to use with the Global datastore.
-
#engine ⇒ String
Modifies the engine listed in a global replication group message.
-
#engine_version ⇒ String
The upgraded version of the cache engine to be run on the clusters in the Global datastore.
-
#global_replication_group_description ⇒ String
A description of the Global datastore.
-
#global_replication_group_id ⇒ String
The name of the Global datastore.
Instance Attribute Details
#apply_immediately ⇒ Boolean
This parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible. Modifications to Global Replication Groups cannot be requested to be applied in PreferredMaintenceWindow.
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |
#automatic_failover_enabled ⇒ Boolean
Determines whether a read replica is automatically promoted to read/write primary if the existing primary encounters a failure.
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
A valid cache node type that you want to scale this Global datastore to.
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to use with the Global datastore. It must be compatible with the major engine version used by the Global datastore.
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
Modifies the engine listed in a global replication group message. The options are valkey, memcached or redis.
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The upgraded version of the cache engine to be run on the clusters in the Global datastore.
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |
#global_replication_group_description ⇒ String
A description of the Global datastore
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |
#global_replication_group_id ⇒ String
The name of the Global datastore
6301 6302 6303 6304 6305 6306 6307 6308 6309 6310 6311 6312 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6301 class ModifyGlobalReplicationGroupMessage < Struct.new( :global_replication_group_id, :apply_immediately, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :global_replication_group_description, :automatic_failover_enabled) SENSITIVE = [] include Aws::Structure end |