Class: Aws::ElastiCache::Types::ModifyReplicationGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ModifyReplicationGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass ModifyReplicationGroupMessage data as a hash:
{
replication_group_id: "String", # required
replication_group_description: "String",
primary_cluster_id: "String",
snapshotting_cluster_id: "String",
automatic_failover_enabled: false,
multi_az_enabled: false,
node_group_id: "String",
cache_security_group_names: ["String"],
security_group_ids: ["String"],
preferred_maintenance_window: "String",
notification_topic_arn: "String",
cache_parameter_group_name: "String",
notification_topic_status: "String",
apply_immediately: false,
engine_version: "String",
auto_minor_version_upgrade: false,
snapshot_retention_limit: 1,
snapshot_window: "String",
cache_node_type: "String",
auth_token: "String",
auth_token_update_strategy: "SET", # accepts SET, ROTATE, DELETE
user_group_ids_to_add: ["UserGroupId"],
user_group_ids_to_remove: ["UserGroupId"],
remove_user_groups: false,
log_delivery_configurations: [
{
log_type: "slow-log", # accepts slow-log, engine-log
destination_type: "cloudwatch-logs", # accepts cloudwatch-logs, kinesis-firehose
destination_details: {
cloud_watch_logs_details: {
log_group: "String",
},
kinesis_firehose_details: {
delivery_stream: "String",
},
},
log_format: "text", # accepts text, json
enabled: false,
},
],
ip_discovery: "ipv4", # accepts ipv4, ipv6
}
Represents the input of a ModifyReplicationGroups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
If
true, this parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible, regardless of thePreferredMaintenanceWindowsetting for the replication group. -
#auth_token ⇒ String
Reserved parameter.
-
#auth_token_update_strategy ⇒ String
Specifies the strategy to use to update the AUTH token.
-
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign.
-
#automatic_failover_enabled ⇒ Boolean
Determines whether a read replica is automatically promoted to read/write primary if the existing primary encounters a failure.
-
#cache_node_type ⇒ String
A valid cache node type that you want to scale this replication group to.
-
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to apply to all of the clusters in this replication group.
-
#cache_security_group_names ⇒ Array<String>
A list of cache security group names to authorize for the clusters in this replication group.
-
#engine_version ⇒ String
The upgraded version of the cache engine to be run on the clusters in the replication group.
-
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either
ipv4|ipv6. -
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfigurationRequest>
Specifies the destination, format and type of the logs.
-
#multi_az_enabled ⇒ Boolean
A flag to indicate MultiAZ is enabled.
-
#node_group_id ⇒ String
Deprecated.
-
#notification_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications are sent.
-
#notification_topic_status ⇒ String
The status of the Amazon SNS notification topic for the replication group.
-
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed.
-
#primary_cluster_id ⇒ String
For replication groups with a single primary, if this parameter is specified, ElastiCache promotes the specified cluster in the specified replication group to the primary role.
-
#remove_user_groups ⇒ Boolean
Removes the user group associated with this replication group.
-
#replication_group_description ⇒ String
A description for the replication group.
-
#replication_group_id ⇒ String
The identifier of the replication group to modify.
-
#security_group_ids ⇒ Array<String>
Specifies the VPC Security Groups associated with the clusters in the replication group.
-
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic node group (shard) snapshots before deleting them.
-
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of the node group (shard) specified by
SnapshottingClusterId. -
#snapshotting_cluster_id ⇒ String
The cluster ID that is used as the daily snapshot source for the replication group.
-
#user_group_ids_to_add ⇒ Array<String>
The ID of the user group you are associating with the replication group.
-
#user_group_ids_to_remove ⇒ Array<String>
The ID of the user group to disassociate from the replication group, meaning the users in the group no longer can access the replication group.
Instance Attribute Details
#apply_immediately ⇒ Boolean
If true, this parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible, regardless of the PreferredMaintenanceWindow setting for the replication group.
If false, changes to the nodes in the replication group are applied on the next maintenance reboot, or the next failure reboot, whichever occurs first.
Valid values: true | false
Default: false
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auth_token ⇒ String
Reserved parameter. The password used to access a password protected server. This parameter must be specified with the ‘auth-token-update-strategy ` parameter. Password constraints:
-
Must be only printable ASCII characters
-
Must be at least 16 characters and no more than 128 characters in length
-
Cannot contain any of the following characters: ‘/’, ‘“’, or ‘@’, ‘%’
For more information, see AUTH password at [AUTH].
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auth_token_update_strategy ⇒ String
Specifies the strategy to use to update the AUTH token. This parameter must be specified with the auth-token parameter. Possible values:
-
Rotate
-
Set
For more information, see [Authenticating Users with Redis AUTH]
[1]: docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/auth.html
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign. This parameter is disabled for previous versions.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#automatic_failover_enabled ⇒ Boolean
Determines whether a read replica is automatically promoted to read/write primary if the existing primary encounters a failure.
Valid values: true | false
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
A valid cache node type that you want to scale this replication group to.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to apply to all of the clusters in this replication group. This change is asynchronously applied as soon as possible for parameters when the ApplyImmediately parameter is specified as true for this request.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_security_group_names ⇒ Array<String>
A list of cache security group names to authorize for the clusters in this replication group. This change is asynchronously applied as soon as possible.
This parameter can be used only with replication group containing clusters running outside of an Amazon Virtual Private Cloud (Amazon VPC).
Constraints: Must contain no more than 255 alphanumeric characters. Must not be Default.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The upgraded version of the cache engine to be run on the clusters in the replication group.
Important: You can upgrade to a newer engine version (see [Selecting a Cache Engine and Version]), but you cannot downgrade to an earlier engine version. If you want to use an earlier engine version, you must delete the existing replication group and create it anew with the earlier engine version.
[1]: docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either ipv4 | ipv6. IPv6 is supported for workloads using Redis engine version 6.2 onward or Memcached engine version 1.6.6 on all instances built on the [Nitro system].
[1]: aws.amazon.com/ec2/nitro/
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfigurationRequest>
Specifies the destination, format and type of the logs.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#multi_az_enabled ⇒ Boolean
A flag to indicate MultiAZ is enabled.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#node_group_id ⇒ String
Deprecated. This parameter is not used.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#notification_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications are sent.
<note markdown=“1”> The Amazon SNS topic owner must be same as the replication group owner.
</note>
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#notification_topic_status ⇒ String
The status of the Amazon SNS notification topic for the replication group. Notifications are sent only if the status is active.
Valid values: active | inactive
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.
Valid values for ddd are:
-
sun -
mon -
tue -
wed -
thu -
fri -
sat
Example: sun:23:00-mon:01:30
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#primary_cluster_id ⇒ String
For replication groups with a single primary, if this parameter is specified, ElastiCache promotes the specified cluster in the specified replication group to the primary role. The nodes of all other clusters in the replication group are read replicas.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#remove_user_groups ⇒ Boolean
Removes the user group associated with this replication group.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#replication_group_description ⇒ String
A description for the replication group. Maximum length is 255 characters.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The identifier of the replication group to modify.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
Specifies the VPC Security Groups associated with the clusters in the replication group.
This parameter can be used only with replication group containing clusters running in an Amazon Virtual Private Cloud (Amazon VPC).
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic node group (shard) snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for 5 days before being deleted.
Important If the value of SnapshotRetentionLimit is set to zero (0), backups are turned off.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of the node group (shard) specified by SnapshottingClusterId.
Example: 05:00-09:00
If you do not specify this parameter, ElastiCache automatically chooses an appropriate time range.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshotting_cluster_id ⇒ String
The cluster ID that is used as the daily snapshot source for the replication group. This parameter cannot be set for Redis (cluster mode enabled) replication groups.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#user_group_ids_to_add ⇒ Array<String>
The ID of the user group you are associating with the replication group.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#user_group_ids_to_remove ⇒ Array<String>
The ID of the user group to disassociate from the replication group, meaning the users in the group no longer can access the replication group.
6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 6857 6858 6859 6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6843 class ModifyReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :primary_cluster_id, :snapshotting_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :node_group_id, :cache_security_group_names, :security_group_ids, :preferred_maintenance_window, :notification_topic_arn, :cache_parameter_group_name, :notification_topic_status, :apply_immediately, :engine_version, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :cache_node_type, :auth_token, :auth_token_update_strategy, :user_group_ids_to_add, :user_group_ids_to_remove, :remove_user_groups, :log_delivery_configurations, :ip_discovery) SENSITIVE = [] include Aws::Structure end |