Class: Aws::ElastiCache::Types::ModifyReplicationGroupShardConfigurationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ModifyReplicationGroupShardConfigurationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass ModifyReplicationGroupShardConfigurationMessage data as a hash:
{
replication_group_id: "String", # required
node_group_count: 1, # required
apply_immediately: false, # required
resharding_configuration: [
{
node_group_id: "AllowedNodeGroupId",
preferred_availability_zones: ["String"],
},
],
node_groups_to_remove: ["AllowedNodeGroupId"],
node_groups_to_retain: ["AllowedNodeGroupId"],
}
Represents the input for a ModifyReplicationGroupShardConfiguration operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
Indicates that the shard reconfiguration process begins immediately.
-
#node_group_count ⇒ Integer
The number of node groups (shards) that results from the modification of the shard configuration.
-
#node_groups_to_remove ⇒ Array<String>
If the value of
NodeGroupCountis less than the current number of node groups (shards), then eitherNodeGroupsToRemoveorNodeGroupsToRetainis required. -
#node_groups_to_retain ⇒ Array<String>
If the value of
NodeGroupCountis less than the current number of node groups (shards), then eitherNodeGroupsToRemoveorNodeGroupsToRetainis required. -
#replication_group_id ⇒ String
The name of the Redis (cluster mode enabled) cluster (replication group) on which the shards are to be configured.
-
#resharding_configuration ⇒ Array<Types::ReshardingConfiguration>
Specifies the preferred availability zones for each node group in the cluster.
Instance Attribute Details
#apply_immediately ⇒ Boolean
Indicates that the shard reconfiguration process begins immediately. At present, the only permitted value for this parameter is true.
Value: true
6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6958 class ModifyReplicationGroupShardConfigurationMessage < Struct.new( :replication_group_id, :node_group_count, :apply_immediately, :resharding_configuration, :node_groups_to_remove, :node_groups_to_retain) SENSITIVE = [] include Aws::Structure end |
#node_group_count ⇒ Integer
The number of node groups (shards) that results from the modification of the shard configuration.
6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6958 class ModifyReplicationGroupShardConfigurationMessage < Struct.new( :replication_group_id, :node_group_count, :apply_immediately, :resharding_configuration, :node_groups_to_remove, :node_groups_to_retain) SENSITIVE = [] include Aws::Structure end |
#node_groups_to_remove ⇒ Array<String>
If the value of NodeGroupCount is less than the current number of node groups (shards), then either NodeGroupsToRemove or NodeGroupsToRetain is required. NodeGroupsToRemove is a list of ‘NodeGroupId`s to remove from the cluster.
ElastiCache for Redis will attempt to remove all node groups listed by NodeGroupsToRemove from the cluster.
6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6958 class ModifyReplicationGroupShardConfigurationMessage < Struct.new( :replication_group_id, :node_group_count, :apply_immediately, :resharding_configuration, :node_groups_to_remove, :node_groups_to_retain) SENSITIVE = [] include Aws::Structure end |
#node_groups_to_retain ⇒ Array<String>
If the value of NodeGroupCount is less than the current number of node groups (shards), then either NodeGroupsToRemove or NodeGroupsToRetain is required. NodeGroupsToRetain is a list of ‘NodeGroupId`s to retain in the cluster.
ElastiCache for Redis will attempt to remove all node groups except those listed by NodeGroupsToRetain from the cluster.
6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6958 class ModifyReplicationGroupShardConfigurationMessage < Struct.new( :replication_group_id, :node_group_count, :apply_immediately, :resharding_configuration, :node_groups_to_remove, :node_groups_to_retain) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The name of the Redis (cluster mode enabled) cluster (replication group) on which the shards are to be configured.
6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6958 class ModifyReplicationGroupShardConfigurationMessage < Struct.new( :replication_group_id, :node_group_count, :apply_immediately, :resharding_configuration, :node_groups_to_remove, :node_groups_to_retain) SENSITIVE = [] include Aws::Structure end |
#resharding_configuration ⇒ Array<Types::ReshardingConfiguration>
Specifies the preferred availability zones for each node group in the cluster. If the value of NodeGroupCount is greater than the current number of node groups (shards), you can use this parameter to specify the preferred availability zones of the cluster’s shards. If you omit this parameter ElastiCache selects availability zones for you.
You can specify this parameter only if the value of NodeGroupCount is greater than the current number of node groups (shards).
6958 6959 6960 6961 6962 6963 6964 6965 6966 6967 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6958 class ModifyReplicationGroupShardConfigurationMessage < Struct.new( :replication_group_id, :node_group_count, :apply_immediately, :resharding_configuration, :node_groups_to_remove, :node_groups_to_retain) SENSITIVE = [] include Aws::Structure end |