Class: Aws::ElastiCache::Types::ModifyServerlessCacheRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ModifyServerlessCacheRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_usage_limits ⇒ Types::CacheUsageLimits
Modify the cache usage limit for the serverless cache.
-
#daily_snapshot_time ⇒ String
The daily time during which Elasticache begins taking a daily snapshot of the serverless cache.
-
#description ⇒ String
User provided description for the serverless cache.
-
#engine ⇒ String
Modifies the engine listed in a serverless cache request.
-
#major_engine_version ⇒ String
Modifies the engine vesion listed in a serverless cache request.
-
#remove_user_group ⇒ Boolean
The identifier of the UserGroup to be removed from association with the Valkey and Redis OSS serverless cache.
-
#security_group_ids ⇒ Array<String>
The new list of VPC security groups to be associated with the serverless cache.
-
#serverless_cache_name ⇒ String
User-provided identifier for the serverless cache to be modified.
-
#snapshot_retention_limit ⇒ Integer
The number of days for which Elasticache retains automatic snapshots before deleting them.
-
#user_group_id ⇒ String
The identifier of the UserGroup to be associated with the serverless cache.
Instance Attribute Details
#cache_usage_limits ⇒ Types::CacheUsageLimits
Modify the cache usage limit for the serverless cache.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#daily_snapshot_time ⇒ String
The daily time during which Elasticache begins taking a daily snapshot of the serverless cache. Available for Valkey, Redis OSS and Serverless Memcached only. The default is NULL, i.e. the existing snapshot time configured for the cluster is not removed.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
User provided description for the serverless cache. Default = NULL, i.e. the existing description is not removed/modified. The description has a maximum length of 255 characters.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
Modifies the engine listed in a serverless cache request. The options are valkey, memcached or redis.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
Modifies the engine vesion listed in a serverless cache request.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#remove_user_group ⇒ Boolean
The identifier of the UserGroup to be removed from association with the Valkey and Redis OSS serverless cache. Available for Valkey and Redis OSS only. Default is NULL.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The new list of VPC security groups to be associated with the serverless cache. Populating this list means the current VPC security groups will be removed. This security group is used to authorize traffic access for the VPC end-point (private-link). Default = NULL - the existing list of VPC security groups is not removed.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#serverless_cache_name ⇒ String
User-provided identifier for the serverless cache to be modified.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_limit ⇒ Integer
The number of days for which Elasticache retains automatic snapshots before deleting them. Available for Valkey, Redis OSS and Serverless Memcached only. Default = NULL, i.e. the existing snapshot-retention-limit will not be removed or modified. The maximum value allowed is 35 days.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#user_group_id ⇒ String
The identifier of the UserGroup to be associated with the serverless cache. Available for Valkey and Redis OSS only. Default is NULL - the existing UserGroup is not removed.
6816 6817 6818 6819 6820 6821 6822 6823 6824 6825 6826 6827 6828 6829 |
# File 'lib/aws-sdk-elasticache/types.rb', line 6816 class ModifyServerlessCacheRequest < Struct.new( :serverless_cache_name, :description, :cache_usage_limits, :remove_user_group, :user_group_id, :security_group_ids, :snapshot_retention_limit, :daily_snapshot_time, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |