Class: Aws::ElastiCache::Types::NodeGroupConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::NodeGroupConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Node group (shard) configuration options. Each node group (shard)
configuration has the following: Slots, PrimaryAvailabilityZone,
ReplicaAvailabilityZones, ReplicaCount.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#node_group_id ⇒ String
Either the ElastiCache supplied 4-digit id or a user supplied id for the node group these configuration values apply to.
-
#primary_availability_zone ⇒ String
The Availability Zone where the primary node of this node group (shard) is launched.
-
#primary_outpost_arn ⇒ String
The outpost ARN of the primary node.
-
#replica_availability_zones ⇒ Array<String>
A list of Availability Zones to be used for the read replicas.
-
#replica_count ⇒ Integer
The number of read replica nodes in this node group (shard).
-
#replica_outpost_arns ⇒ Array<String>
The outpost ARN of the node replicas.
-
#slots ⇒ String
A string that specifies the keyspace for a particular node group.
Instance Attribute Details
#node_group_id ⇒ String
Either the ElastiCache supplied 4-digit id or a user supplied id for the node group these configuration values apply to.
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7016 class NodeGroupConfiguration < Struct.new( :node_group_id, :slots, :replica_count, :primary_availability_zone, :replica_availability_zones, :primary_outpost_arn, :replica_outpost_arns) SENSITIVE = [] include Aws::Structure end |
#primary_availability_zone ⇒ String
The Availability Zone where the primary node of this node group (shard) is launched.
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7016 class NodeGroupConfiguration < Struct.new( :node_group_id, :slots, :replica_count, :primary_availability_zone, :replica_availability_zones, :primary_outpost_arn, :replica_outpost_arns) SENSITIVE = [] include Aws::Structure end |
#primary_outpost_arn ⇒ String
The outpost ARN of the primary node.
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7016 class NodeGroupConfiguration < Struct.new( :node_group_id, :slots, :replica_count, :primary_availability_zone, :replica_availability_zones, :primary_outpost_arn, :replica_outpost_arns) SENSITIVE = [] include Aws::Structure end |
#replica_availability_zones ⇒ Array<String>
A list of Availability Zones to be used for the read replicas. The
number of Availability Zones in this list must match the value of
ReplicaCount or ReplicasPerNodeGroup if not specified.
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7016 class NodeGroupConfiguration < Struct.new( :node_group_id, :slots, :replica_count, :primary_availability_zone, :replica_availability_zones, :primary_outpost_arn, :replica_outpost_arns) SENSITIVE = [] include Aws::Structure end |
#replica_count ⇒ Integer
The number of read replica nodes in this node group (shard).
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7016 class NodeGroupConfiguration < Struct.new( :node_group_id, :slots, :replica_count, :primary_availability_zone, :replica_availability_zones, :primary_outpost_arn, :replica_outpost_arns) SENSITIVE = [] include Aws::Structure end |
#replica_outpost_arns ⇒ Array<String>
The outpost ARN of the node replicas.
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7016 class NodeGroupConfiguration < Struct.new( :node_group_id, :slots, :replica_count, :primary_availability_zone, :replica_availability_zones, :primary_outpost_arn, :replica_outpost_arns) SENSITIVE = [] include Aws::Structure end |
#slots ⇒ String
A string that specifies the keyspace for a particular node group.
Keyspaces range from 0 to 16,383. The string is in the format
startkey-endkey.
Example: "0-3999"
7016 7017 7018 7019 7020 7021 7022 7023 7024 7025 7026 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7016 class NodeGroupConfiguration < Struct.new( :node_group_id, :slots, :replica_count, :primary_availability_zone, :replica_availability_zones, :primary_outpost_arn, :replica_outpost_arns) SENSITIVE = [] include Aws::Structure end |