Class: Aws::ElastiCache::Types::PendingModifiedValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

A group of settings that are applied to the cluster in the future, or that are currently being applied.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_token_statusString

The auth token status

Returns:

  • (String)


7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#cache_node_ids_to_removeArray<String>

A list of cache node IDs that are being removed (or will be removed) from the cluster. A node ID is a 4-digit numeric identifier (0001, 0002, etc.).

Returns:

  • (Array<String>)


7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#cache_node_typeString

The cache node type that this cluster or replication group is scaled to.

Returns:

  • (String)


7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The new cache engine version that the cluster runs.

Returns:

  • (String)


7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationsArray<Types::PendingLogDeliveryConfiguration>

The log delivery configurations being modified



7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#num_cache_nodesInteger

The new number of cache nodes for the cluster.

For clusters running Valkey or Redis OSS, this value must be 1. For clusters running Memcached, this value must be between 1 and 40.

Returns:

  • (Integer)


7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#scale_configTypes::ScaleConfig

The scaling configuration changes that are pending for the Memcached cluster.

Returns:



7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#transit_encryption_enabledBoolean

A flag that enables in-transit encryption when set to true.

Returns:

  • (Boolean)


7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end

#transit_encryption_modeString

A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.

Returns:

  • (String)


7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
# File 'lib/aws-sdk-elasticache/types.rb', line 7406

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations,
  :transit_encryption_enabled,
  :transit_encryption_mode,
  :scale_config)
  SENSITIVE = []
  include Aws::Structure
end