Class: Aws::ElastiCache::Types::PurchaseReservedCacheNodesOfferingMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::PurchaseReservedCacheNodesOfferingMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass PurchaseReservedCacheNodesOfferingMessage data as a hash:
{
reserved_cache_nodes_offering_id: "String", # required
reserved_cache_node_id: "String",
cache_node_count: 1,
tags: [
{
key: "String",
value: "String",
},
],
}
Represents the input of a PurchaseReservedCacheNodesOffering operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_node_count ⇒ Integer
The number of cache node instances to reserve.
-
#reserved_cache_node_id ⇒ String
A customer-specified identifier to track this reservation.
-
#reserved_cache_nodes_offering_id ⇒ String
The ID of the reserved cache node offering to purchase.
-
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource.
Instance Attribute Details
#cache_node_count ⇒ Integer
The number of cache node instances to reserve.
Default: 1
7654 7655 7656 7657 7658 7659 7660 7661 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7654 class PurchaseReservedCacheNodesOfferingMessage < Struct.new( :reserved_cache_nodes_offering_id, :reserved_cache_node_id, :cache_node_count, :tags) SENSITIVE = [] include Aws::Structure end |
#reserved_cache_node_id ⇒ String
A customer-specified identifier to track this reservation.
<note markdown=“1”> The Reserved Cache Node ID is an unique customer-specified identifier to track this reservation. If this parameter is not specified, ElastiCache automatically generates an identifier for the reservation.
</note>
Example: myreservationID
7654 7655 7656 7657 7658 7659 7660 7661 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7654 class PurchaseReservedCacheNodesOfferingMessage < Struct.new( :reserved_cache_nodes_offering_id, :reserved_cache_node_id, :cache_node_count, :tags) SENSITIVE = [] include Aws::Structure end |
#reserved_cache_nodes_offering_id ⇒ String
The ID of the reserved cache node offering to purchase.
Example: 438012d3-4052-4cc7-b2e3-8d3372e0e706
7654 7655 7656 7657 7658 7659 7660 7661 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7654 class PurchaseReservedCacheNodesOfferingMessage < Struct.new( :reserved_cache_nodes_offering_id, :reserved_cache_node_id, :cache_node_count, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.
7654 7655 7656 7657 7658 7659 7660 7661 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7654 class PurchaseReservedCacheNodesOfferingMessage < Struct.new( :reserved_cache_nodes_offering_id, :reserved_cache_node_id, :cache_node_count, :tags) SENSITIVE = [] include Aws::Structure end |