Class: Aws::ElastiCache::Types::ResetCacheParameterGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ResetCacheParameterGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass ResetCacheParameterGroupMessage data as a hash:
{
cache_parameter_group_name: "String", # required
reset_all_parameters: false,
parameter_name_values: [
{
parameter_name: "String",
parameter_value: "String",
},
],
}
Represents the input of a ResetCacheParameterGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to reset.
-
#parameter_name_values ⇒ Array<Types::ParameterNameValue>
An array of parameter names to reset to their default values.
-
#reset_all_parameters ⇒ Boolean
If
true, all parameters in the cache parameter group are reset to their default values.
Instance Attribute Details
#cache_parameter_group_name ⇒ String
The name of the cache parameter group to reset.
8630 8631 8632 8633 8634 8635 8636 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8630 class ResetCacheParameterGroupMessage < Struct.new( :cache_parameter_group_name, :reset_all_parameters, :parameter_name_values) SENSITIVE = [] include Aws::Structure end |
#parameter_name_values ⇒ Array<Types::ParameterNameValue>
An array of parameter names to reset to their default values. If ResetAllParameters is true, do not use ParameterNameValues. If ResetAllParameters is false, you must specify the name of at least one parameter to reset.
8630 8631 8632 8633 8634 8635 8636 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8630 class ResetCacheParameterGroupMessage < Struct.new( :cache_parameter_group_name, :reset_all_parameters, :parameter_name_values) SENSITIVE = [] include Aws::Structure end |
#reset_all_parameters ⇒ Boolean
If true, all parameters in the cache parameter group are reset to their default values. If false, only the parameters listed by ParameterNameValues are reset to their default values.
Valid values: true | false
8630 8631 8632 8633 8634 8635 8636 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8630 class ResetCacheParameterGroupMessage < Struct.new( :cache_parameter_group_name, :reset_all_parameters, :parameter_name_values) SENSITIVE = [] include Aws::Structure end |