Class: Aws::ElastiCache::Types::ServerlessCache
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ServerlessCache
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
The resource representing a serverless cache.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the serverless cache.
-
#cache_usage_limits ⇒ Types::CacheUsageLimits
The cache usage limit for the serverless cache.
-
#create_time ⇒ Time
When the serverless cache was created.
-
#daily_snapshot_time ⇒ String
The daily time that a cache snapshot will be created.
-
#description ⇒ String
A description of the serverless cache.
-
#endpoint ⇒ Types::Endpoint
Represents the information required for client programs to connect to a cache node.
-
#engine ⇒ String
The engine the serverless cache is compatible with.
-
#full_engine_version ⇒ String
The name and version number of the engine the serverless cache is compatible with.
-
#kms_key_id ⇒ String
The ID of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt data at rest in the serverless cache.
-
#major_engine_version ⇒ String
The version number of the engine the serverless cache is compatible with.
-
#network_type ⇒ String
The type of IP address protocol used by the serverless cache.
-
#reader_endpoint ⇒ Types::Endpoint
Represents the information required for client programs to connect to a cache node.
-
#security_group_ids ⇒ Array<String>
The IDs of the EC2 security groups associated with the serverless cache.
-
#serverless_cache_name ⇒ String
The unique identifier of the serverless cache.
-
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic snapshots before deleting them.
-
#status ⇒ String
The current status of the serverless cache.
-
#storage_encryption_type ⇒ String
Indicates the type of encryption for data stored at rest in the serverless cache.
-
#subnet_ids ⇒ Array<String>
If no subnet IDs are given and your VPC is in us-west-1, then ElastiCache will select 2 default subnets across AZs in your VPC.
-
#user_group_id ⇒ String
The identifier of the user group associated with the serverless cache.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the serverless cache.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#cache_usage_limits ⇒ Types::CacheUsageLimits
The cache usage limit for the serverless cache.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
When the serverless cache was created.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#daily_snapshot_time ⇒ String
The daily time that a cache snapshot will be created. Default is NULL, i.e. snapshots will not be created at a specific time on a daily basis. Available for Valkey, Redis OSS and Serverless Memcached only.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the serverless cache.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ Types::Endpoint
Represents the information required for client programs to connect to a cache node. This value is read-only.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The engine the serverless cache is compatible with.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#full_engine_version ⇒ String
The name and version number of the engine the serverless cache is compatible with.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ID of the Amazon Web Services Key Management Service (KMS) key that is used to encrypt data at rest in the serverless cache.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
The version number of the engine the serverless cache is compatible with.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
The type of IP address protocol used by the serverless cache. Must
be either ipv4 | ipv6 | dual_stack. ipv6 is only supported
with IPv6-only subnets. If not specified, defaults to ipv4, unless
all provided subnets are IPv6-only, in which case it defaults to
ipv6.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#reader_endpoint ⇒ Types::Endpoint
Represents the information required for client programs to connect to a cache node. This value is read-only.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The IDs of the EC2 security groups associated with the serverless cache.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#serverless_cache_name ⇒ String
The unique identifier of the serverless cache.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic snapshots before deleting them. Available for Valkey, Redis OSS and Serverless Memcached only. The maximum value allowed is 35 days.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the serverless cache. The allowed values are CREATING, AVAILABLE, DELETING, CREATE-FAILED and MODIFYING.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#storage_encryption_type ⇒ String
Indicates the type of encryption for data stored at rest in the
serverless cache. Serverless caches are always encrypted at rest.
The value is sse-elasticache if an ElastiCache service-managed key
is used, or sse-kms if a customer-managed KMS key is used.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
If no subnet IDs are given and your VPC is in us-west-1, then ElastiCache will select 2 default subnets across AZs in your VPC. For all other Regions, if no subnet IDs are given then ElastiCache will select 3 default subnets across AZs in your default VPC.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |
#user_group_id ⇒ String
The identifier of the user group associated with the serverless cache. Available for Valkey and Redis OSS only. Default is NULL.
8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8731 class ServerlessCache < Struct.new( :serverless_cache_name, :description, :create_time, :status, :engine, :major_engine_version, :full_engine_version, :cache_usage_limits, :kms_key_id, :storage_encryption_type, :security_group_ids, :endpoint, :reader_endpoint, :arn, :user_group_id, :subnet_ids, :snapshot_retention_limit, :daily_snapshot_time, :network_type) SENSITIVE = [] include Aws::Structure end |