Class: Aws::ElastiCache::Types::ServerlessCacheConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ServerlessCacheConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
The configuration settings for a specific serverless cache.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine ⇒ String
The engine that the serverless cache is configured with.
-
#major_engine_version ⇒ String
The engine version number that the serverless cache is configured with.
-
#serverless_cache_name ⇒ String
The identifier of a serverless cache.
Instance Attribute Details
#engine ⇒ String
The engine that the serverless cache is configured with.
8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8773 class ServerlessCacheConfiguration < Struct.new( :serverless_cache_name, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
The engine version number that the serverless cache is configured with.
8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8773 class ServerlessCacheConfiguration < Struct.new( :serverless_cache_name, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#serverless_cache_name ⇒ String
The identifier of a serverless cache.
8773 8774 8775 8776 8777 8778 8779 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8773 class ServerlessCacheConfiguration < Struct.new( :serverless_cache_name, :engine, :major_engine_version) SENSITIVE = [] include Aws::Structure end |