Class: Aws::ElastiCache::Types::ServerlessCacheSnapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

The resource representing a serverless cache snapshot. Available for Valkey, Redis OSS and Serverless Memcached only.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of a serverless cache snapshot. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (String)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#bytes_used_for_cacheString

The total size of a serverless cache snapshot, in bytes. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (String)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The date and time that the source serverless cache’s metadata and cache data set was obtained for the snapshot. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (Time)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#expiry_timeTime

The time that the serverless cache snapshot will expire. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (Time)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The ID of the Amazon Web Services Key Management Service (KMS) key of a serverless cache snapshot. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (String)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#serverless_cache_configurationTypes::ServerlessCacheConfiguration

The configuration of the serverless cache, at the time the snapshot was taken. Available for Valkey, Redis OSS and Serverless Memcached only.



8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#serverless_cache_snapshot_nameString

The identifier of a serverless cache snapshot. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (String)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_typeString

The type of snapshot of serverless cache. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (String)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the serverless cache. Available for Valkey, Redis OSS and Serverless Memcached only.

Returns:

  • (String)


8846
8847
8848
8849
8850
8851
8852
8853
8854
8855
8856
8857
8858
# File 'lib/aws-sdk-elasticache/types.rb', line 8846

class ServerlessCacheSnapshot < Struct.new(
  :serverless_cache_snapshot_name,
  :arn,
  :kms_key_id,
  :snapshot_type,
  :status,
  :create_time,
  :expiry_time,
  :bytes_used_for_cache,
  :serverless_cache_configuration)
  SENSITIVE = []
  include Aws::Structure
end