Class: Aws::ElastiCache::Types::ServiceUpdate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

An update that you can apply to your Valkey or Redis OSS clusters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

Indicates whether the service update will be automatically applied once the recommended apply-by date has expired.



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The Elasticache engine to which the update applies. Either Valkey, Redis OSS or Memcached.



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The Elasticache engine version to which the update applies. Either Valkey, Redis OSS or Memcached engine version.



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#estimated_update_timeString

The estimated length of time the service update will take



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_descriptionString

Provides details of the service update



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_end_dateTime

The date after which the service update is no longer available



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_nameString

The unique ID of the service update



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

The recommendend date to apply the service update in order to ensure compliance. For information on compliance, see [Self-Service Security Updates for Compliance].

[1]: docs.aws.amazon.com/AmazonElastiCache/latest/dg/elasticache-compliance.html#elasticache-compliance-self-service



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_release_dateTime

The date when the service update is initially available



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_severityString

The severity of the service update



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_statusString

The status of the service update



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end

#service_update_typeString

Reflects the nature of the service update



8866
8867
8868
8869
8870
8871
8872
8873
8874
8875
8876
8877
8878
8879
8880
8881
# File 'lib/aws-sdk-elasticache/types.rb', line 8866

class ServiceUpdate < Struct.new(
  :service_update_name,
  :service_update_release_date,
  :service_update_end_date,
  :service_update_severity,
  :service_update_recommended_apply_by_date,
  :service_update_status,
  :service_update_description,
  :service_update_type,
  :engine,
  :engine_version,
  :auto_update_after_recommended_apply_by_date,
  :estimated_update_time)
  SENSITIVE = []
  include Aws::Structure
end