Class: Aws::ElastiCache::Types::ServiceUpdatesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ServiceUpdatesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#service_updates ⇒ Array<Types::ServiceUpdate>
A list of service updates.
Instance Attribute Details
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8984 class ServiceUpdatesMessage < Struct.new( :marker, :service_updates) SENSITIVE = [] include Aws::Structure end |
#service_updates ⇒ Array<Types::ServiceUpdate>
A list of service updates
8984 8985 8986 8987 8988 8989 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8984 class ServiceUpdatesMessage < Struct.new( :marker, :service_updates) SENSITIVE = [] include Aws::Structure end |