Class: Aws::ElastiCache::Types::Subnet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Represents the subnet associated with a cluster. This parameter refers to subnets defined in Amazon Virtual Private Cloud (Amazon VPC) and used with ElastiCache.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#subnet_availability_zoneTypes::AvailabilityZone

The Availability Zone associated with the subnet.



9437
9438
9439
9440
9441
9442
9443
9444
# File 'lib/aws-sdk-elasticache/types.rb', line 9437

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :supported_network_types)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_identifierString

The unique identifier for the subnet.

Returns:

  • (String)


9437
9438
9439
9440
9441
9442
9443
9444
# File 'lib/aws-sdk-elasticache/types.rb', line 9437

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :supported_network_types)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_outpostTypes::SubnetOutpost

The outpost ARN of the subnet.



9437
9438
9439
9440
9441
9442
9443
9444
# File 'lib/aws-sdk-elasticache/types.rb', line 9437

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :supported_network_types)
  SENSITIVE = []
  include Aws::Structure
end

#supported_network_typesArray<String>

Either ipv4 | ipv6 | dual_stack. IPv6 is supported for workloads using Valkey 7.2 and above, Redis OSS engine version 6.2 to 7.1 or Memcached engine version 1.6.6 and above on all instances built on the Nitro system.

Returns:

  • (Array<String>)


9437
9438
9439
9440
9441
9442
9443
9444
# File 'lib/aws-sdk-elasticache/types.rb', line 9437

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :supported_network_types)
  SENSITIVE = []
  include Aws::Structure
end