Class: Aws::ElastiCache::Types::UpdateAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::UpdateAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
The status of the service update for a specific replication group
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_cluster_id ⇒ String
The ID of the cache cluster.
-
#cache_node_update_status ⇒ Array<Types::CacheNodeUpdateStatus>
The status of the service update on the cache node.
-
#engine ⇒ String
The Elasticache engine to which the update applies.
-
#estimated_update_time ⇒ String
The estimated length of time for the update to complete.
-
#node_group_update_status ⇒ Array<Types::NodeGroupUpdateStatus>
The status of the service update on the node group.
-
#nodes_updated ⇒ String
The progress of the service update on the replication group.
-
#replication_group_id ⇒ String
The ID of the replication group.
-
#service_update_name ⇒ String
The unique ID of the service update.
-
#service_update_recommended_apply_by_date ⇒ Time
The recommended date to apply the service update to ensure compliance.
-
#service_update_release_date ⇒ Time
The date the update is first available.
-
#service_update_severity ⇒ String
The severity of the service update.
-
#service_update_status ⇒ String
The status of the service update.
-
#service_update_type ⇒ String
Reflects the nature of the service update.
-
#sla_met ⇒ String
If yes, all nodes in the replication group have been updated by the recommended apply-by date.
-
#update_action_available_date ⇒ Time
The date that the service update is available to a replication group.
-
#update_action_status ⇒ String
The status of the update action.
-
#update_action_status_modified_date ⇒ Time
The date when the UpdateActionStatus was last modified.
Instance Attribute Details
#cache_cluster_id ⇒ String
The ID of the cache cluster
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#cache_node_update_status ⇒ Array<Types::CacheNodeUpdateStatus>
The status of the service update on the cache node
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The Elasticache engine to which the update applies. Either Valkey, Redis OSS or Memcached.
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#estimated_update_time ⇒ String
The estimated length of time for the update to complete
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#node_group_update_status ⇒ Array<Types::NodeGroupUpdateStatus>
The status of the service update on the node group
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#nodes_updated ⇒ String
The progress of the service update on the replication group
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The ID of the replication group
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#service_update_name ⇒ String
The unique ID of the service update
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#service_update_recommended_apply_by_date ⇒ Time
The recommended date to apply the service update to ensure compliance. For information on compliance, see [Self-Service Security Updates for Compliance].
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#service_update_release_date ⇒ Time
The date the update is first available
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#service_update_severity ⇒ String
The severity of the service update
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#service_update_status ⇒ String
The status of the service update
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#service_update_type ⇒ String
Reflects the nature of the service update
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#sla_met ⇒ String
If yes, all nodes in the replication group have been updated by the recommended apply-by date. If no, at least one node in the replication group have not been updated by the recommended apply-by date. If N/A, the replication group was created after the recommended apply-by date.
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#update_action_available_date ⇒ Time
The date that the service update is available to a replication group
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#update_action_status ⇒ String
The status of the update action
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |
#update_action_status_modified_date ⇒ Time
The date when the UpdateActionStatus was last modified
9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 9745 9746 9747 9748 9749 9750 9751 9752 9753 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9733 class UpdateAction < Struct.new( :replication_group_id, :cache_cluster_id, :service_update_name, :service_update_release_date, :service_update_severity, :service_update_status, :service_update_recommended_apply_by_date, :service_update_type, :update_action_available_date, :update_action_status, :nodes_updated, :update_action_status_modified_date, :sla_met, :node_group_update_status, :cache_node_update_status, :estimated_update_time, :engine) SENSITIVE = [] include Aws::Structure end |