Class: Aws::ElastiCache::Waiters::CacheClusterAvailable
- Inherits:
-
Object
- Object
- Aws::ElastiCache::Waiters::CacheClusterAvailable
- Defined in:
- lib/aws-sdk-elasticache/waiters.rb,
sig/waiters.rbs
Overview
Wait until ElastiCache cluster is available.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CacheClusterAvailable
constructor
A new instance of CacheClusterAvailable.
-
#wait(params = {}) ⇒ Types::CacheClusterMessage
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CacheClusterAvailable
Returns a new instance of CacheClusterAvailable.
88 89 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 88
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
138 139 140 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 138 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::CacheClusterMessage
Returns a response object which responds to the following methods:
- #marker => String
- #cache_clusters => Array<Types::CacheCluster>
133 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 133
def wait: (
|