Class: Aws::ElastiCache::Waiters::CacheClusterDeleted

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-elasticache/waiters.rb,
sig/waiters.rbs

Overview

Wait until ElastiCache cluster is deleted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ CacheClusterDeleted

Returns a new instance of CacheClusterDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


151
152
# File 'lib/aws-sdk-elasticache/waiters.rb', line 151

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



218
219
220
# File 'lib/aws-sdk-elasticache/waiters.rb', line 218

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::CacheClusterMessage

Returns a response object which responds to the following methods:

Options Hash (params):

  • :cache_cluster_id (String)

    The user-supplied cluster identifier. If this parameter is specified, only information about that specific cluster is returned. This parameter isn't case sensitive.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: minimum 20; maximum 100.

  • :marker (String)

    An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  • :show_cache_node_info (Boolean)

    An optional flag that can be included in the DescribeCacheCluster request to retrieve information about the individual cache nodes.

  • :show_cache_clusters_not_in_replication_groups (Boolean)

    An optional flag that can be included in the DescribeCacheCluster request to show only nodes (API/CLI: clusters) that are not members of a replication group. In practice, this means Memcached and single node Valkey or Redis OSS clusters.

Returns:



213
# File 'lib/aws-sdk-elasticache/waiters.rb', line 213

def wait: (