Class: Aws::ElastiCache::Waiters::ReplicationGroupAvailable

Inherits:
Object
  • Object
show all
Defined in:
lib/aws-sdk-elasticache/waiters.rb,
sig/waiters.rbs

Overview

Wait until ElastiCache replication group is available.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ ReplicationGroupAvailable

Returns a new instance of ReplicationGroupAvailable.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 40
  • :delay (Integer) — default: 15
  • :before_attempt (Proc)
  • :before_wait (Proc)


231
232
# File 'lib/aws-sdk-elasticache/waiters.rb', line 231

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



263
264
265
# File 'lib/aws-sdk-elasticache/waiters.rb', line 263

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::ReplicationGroupMessage

Returns a response object which responds to the following methods:

Options Hash (params):

  • :replication_group_id (String)

    The identifier for the replication group to be described. This parameter is not case sensitive.

    If you do not specify this parameter, information about all replication groups is returned.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: minimum 20; maximum 100.

  • :marker (String)

    An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:



258
# File 'lib/aws-sdk-elasticache/waiters.rb', line 258

def wait: (