Method: Aws::ElastiCache::Types::CreateReplicationGroupMessage#cache_node_type
- Defined in:
- lib/aws-sdk-elasticache/types.rb
#cache_node_type ⇒ String
The compute and memory capacity of the nodes in the node group (shard).
The following node types are supported by ElastiCache. Generally speaking, the current generation types provide more memory and computational power at lower cost when compared to their equivalent previous generation counterparts.
-
General purpose:
-
Current generation:
**M7g node types**:
cache.m7g.large,cache.m7g.xlarge,cache.m7g.2xlarge,cache.m7g.4xlarge,cache.m7g.8xlarge,cache.m7g.12xlarge,cache.m7g.16xlarge<note markdown=“1”> For region availability, see [Supported Node Types]
</note>**M6g node types** (available only for Redis OSS engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward):
cache.m6g.large,cache.m6g.xlarge,cache.m6g.2xlarge,cache.m6g.4xlarge,cache.m6g.8xlarge,cache.m6g.12xlarge,cache.m6g.16xlarge**M5 node types:**
cache.m5.large,cache.m5.xlarge,cache.m5.2xlarge,cache.m5.4xlarge,cache.m5.12xlarge,cache.m5.24xlarge**M4 node types:**
cache.m4.large,cache.m4.xlarge,cache.m4.2xlarge,cache.m4.4xlarge,cache.m4.10xlarge**T4g node types** (available only for Redis OSS engine version 5.0.6 onward and Memcached engine version 1.5.16 onward):
cache.t4g.micro,cache.t4g.small,cache.t4g.medium**T3 node types:**
cache.t3.micro,cache.t3.small,cache.t3.medium**T2 node types:**
cache.t2.micro,cache.t2.small,cache.t2.medium -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**T1 node types:**
cache.t1.micro**M1 node types:**
cache.m1.small,cache.m1.medium,cache.m1.large,cache.m1.xlarge**M3 node types:**
cache.m3.medium,cache.m3.large,cache.m3.xlarge,cache.m3.2xlarge
-
-
Compute optimized:
-
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**C1 node types:**
cache.c1.xlarge
-
-
Memory optimized:
-
Current generation:
**R7g node types**:
cache.r7g.large,cache.r7g.xlarge,cache.r7g.2xlarge,cache.r7g.4xlarge,cache.r7g.8xlarge,cache.r7g.12xlarge,cache.r7g.16xlarge<note markdown=“1”> For region availability, see [Supported Node Types]
</note>**R6g node types** (available only for Redis OSS engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward):
cache.r6g.large,cache.r6g.xlarge,cache.r6g.2xlarge,cache.r6g.4xlarge,cache.r6g.8xlarge,cache.r6g.12xlarge,cache.r6g.16xlarge**R5 node types:**
cache.r5.large,cache.r5.xlarge,cache.r5.2xlarge,cache.r5.4xlarge,cache.r5.12xlarge,cache.r5.24xlarge**R4 node types:**
cache.r4.large,cache.r4.xlarge,cache.r4.2xlarge,cache.r4.4xlarge,cache.r4.8xlarge,cache.r4.16xlarge -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**M2 node types:**
cache.m2.xlarge,cache.m2.2xlarge,cache.m2.4xlarge**R3 node types:**
cache.r3.large,cache.r3.xlarge,cache.r3.2xlarge,cache.r3.4xlarge,cache.r3.8xlarge
-
**Additional node type info**
-
All current generation instance types are created in Amazon VPC by default.
-
Valkey or Redis OSS append-only files (AOF) are not supported for T1 or T2 instances.
-
Valkey or Redis OSS Multi-AZ with automatic failover is not supported on T1 instances.
-
The configuration variables
appendonlyandappendfsyncare not supported on Valkey, or on Redis OSS version 2.8.22 and later.
2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2824 class CreateReplicationGroupMessage < Struct.new( :replication_group_id, :replication_group_description, :global_replication_group_id, :primary_cluster_id, :automatic_failover_enabled, :multi_az_enabled, :num_cache_clusters, :preferred_cache_cluster_a_zs, :num_node_groups, :replicas_per_node_group, :node_group_configuration, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :transit_encryption_enabled, :at_rest_encryption_enabled, :kms_key_id, :user_group_ids, :log_delivery_configurations, :data_tiering_enabled, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :serverless_cache_snapshot_name) SENSITIVE = [] include Aws::Structure end |