Class: Aws::ElastiCache::Types::CreateCacheClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::CreateCacheClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass CreateCacheClusterMessage data as a hash:
{
cache_cluster_id: "String", # required
replication_group_id: "String",
az_mode: "single-az", # accepts single-az, cross-az
preferred_availability_zone: "String",
preferred_availability_zones: ["String"],
num_cache_nodes: 1,
cache_node_type: "String",
engine: "String",
engine_version: "String",
cache_parameter_group_name: "String",
cache_subnet_group_name: "String",
cache_security_group_names: ["String"],
security_group_ids: ["String"],
tags: [
{
key: "String",
value: "String",
},
],
snapshot_arns: ["String"],
snapshot_name: "String",
preferred_maintenance_window: "String",
port: 1,
notification_topic_arn: "String",
auto_minor_version_upgrade: false,
snapshot_retention_limit: 1,
snapshot_window: "String",
auth_token: "String",
outpost_mode: "single-outpost", # accepts single-outpost, cross-outpost
preferred_outpost_arn: "String",
preferred_outpost_arns: ["String"],
log_delivery_configurations: [
{
log_type: "slow-log", # accepts slow-log, engine-log
destination_type: "cloudwatch-logs", # accepts cloudwatch-logs, kinesis-firehose
destination_details: {
cloud_watch_logs_details: {
log_group: "String",
},
kinesis_firehose_details: {
delivery_stream: "String",
},
},
log_format: "text", # accepts text, json
enabled: false,
},
],
transit_encryption_enabled: false,
network_type: "ipv4", # accepts ipv4, ipv6, dual_stack
ip_discovery: "ipv4", # accepts ipv4, ipv6
}
Represents the input of a CreateCacheCluster operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_token ⇒ String
**Reserved parameter.** The password used to access a password protected server.
-
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign.
-
#az_mode ⇒ String
Specifies whether the nodes in this Memcached cluster are created in a single Availability Zone or created across multiple Availability Zones in the cluster’s region.
-
#cache_cluster_id ⇒ String
The node group (shard) identifier.
-
#cache_node_type ⇒ String
The compute and memory capacity of the nodes in the node group (shard).
-
#cache_parameter_group_name ⇒ String
The name of the parameter group to associate with this cluster.
-
#cache_security_group_names ⇒ Array<String>
A list of security group names to associate with this cluster.
-
#cache_subnet_group_name ⇒ String
The name of the subnet group to be used for the cluster.
-
#engine ⇒ String
The name of the cache engine to be used for this cluster.
-
#engine_version ⇒ String
The version number of the cache engine to be used for this cluster.
-
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either
ipv4|ipv6. -
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfigurationRequest>
Specifies the destination, format and type of the logs.
-
#network_type ⇒ String
Must be either
ipv4|ipv6|dual_stack. -
#notification_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) topic to which notifications are sent.
-
#num_cache_nodes ⇒ Integer
The initial number of cache nodes that the cluster has.
-
#outpost_mode ⇒ String
Specifies whether the nodes in the cluster are created in a single outpost or across multiple outposts.
-
#port ⇒ Integer
The port number on which each of the cache nodes accepts connections.
-
#preferred_availability_zone ⇒ String
The EC2 Availability Zone in which the cluster is created.
-
#preferred_availability_zones ⇒ Array<String>
A list of the Availability Zones in which cache nodes are created.
-
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed.
-
#preferred_outpost_arn ⇒ String
The outpost ARN in which the cache cluster is created.
-
#preferred_outpost_arns ⇒ Array<String>
The outpost ARNs in which the cache cluster is created.
-
#replication_group_id ⇒ String
The ID of the replication group to which this cluster should belong.
-
#security_group_ids ⇒ Array<String>
One or more VPC security groups associated with the cluster.
-
#snapshot_arns ⇒ Array<String>
A single-element string list containing an Amazon Resource Name (ARN) that uniquely identifies a Redis RDB snapshot file stored in Amazon S3.
-
#snapshot_name ⇒ String
The name of a Redis snapshot from which to restore data into the new node group (shard).
-
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic snapshots before deleting them.
-
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your node group (shard).
-
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource.
-
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true.
Instance Attribute Details
#auth_token ⇒ String
**Reserved parameter.** The password used to access a password protected server.
Password constraints:
-
Must be only printable ASCII characters.
-
Must be at least 16 characters and no more than 128 characters in length.
-
The only permitted printable special characters are !, &, #, $, ^, <, >, and -. Other printable special characters cannot be used in the AUTH token.
For more information, see [AUTH password] at redis.io/commands/AUTH.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign. This parameter is disabled for previous versions.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#az_mode ⇒ String
Specifies whether the nodes in this Memcached cluster are created in a single Availability Zone or created across multiple Availability Zones in the cluster’s region.
This parameter is only supported for Memcached clusters.
If the AZMode and PreferredAvailabilityZones are not specified, ElastiCache assumes single-az mode.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_cluster_id ⇒ String
The node group (shard) identifier. This parameter is stored as a lowercase string.
Constraints:
-
A name must contain from 1 to 50 alphanumeric characters or hyphens.
-
The first character must be a letter.
-
A name cannot end with a hyphen or contain two consecutive hyphens.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
The compute and memory capacity of the nodes in the node group (shard).
The following node types are supported by ElastiCache. Generally speaking, the current generation types provide more memory and computational power at lower cost when compared to their equivalent previous generation counterparts.
-
General purpose:
-
Current generation:
**M6g node types** (available only for Redis engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward):
cache.m6g.large,cache.m6g.xlarge,cache.m6g.2xlarge,cache.m6g.4xlarge,cache.m6g.8xlarge,cache.m6g.12xlarge,cache.m6g.16xlarge<note markdown=“1”> For region availability, see [Supported Node Types]
</note>**M5 node types:**
cache.m5.large,cache.m5.xlarge,cache.m5.2xlarge,cache.m5.4xlarge,cache.m5.12xlarge,cache.m5.24xlarge**M4 node types:**
cache.m4.large,cache.m4.xlarge,cache.m4.2xlarge,cache.m4.4xlarge,cache.m4.10xlarge**T4g node types** (available only for Redis engine version 5.0.6 onward and Memcached engine version 1.5.16 onward):
cache.t4g.micro,cache.t4g.small,cache.t4g.medium**T3 node types:**
cache.t3.micro,cache.t3.small,cache.t3.medium**T2 node types:**
cache.t2.micro,cache.t2.small,cache.t2.medium -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**T1 node types:**
cache.t1.micro**M1 node types:**
cache.m1.small,cache.m1.medium,cache.m1.large,cache.m1.xlarge**M3 node types:**
cache.m3.medium,cache.m3.large,cache.m3.xlarge,cache.m3.2xlarge
-
-
Compute optimized:
-
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**C1 node types:**
cache.c1.xlarge
-
-
Memory optimized:
-
Current generation:
**R6g node types** (available only for Redis engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward).
cache.r6g.large,cache.r6g.xlarge,cache.r6g.2xlarge,cache.r6g.4xlarge,cache.r6g.8xlarge,cache.r6g.12xlarge,cache.r6g.16xlarge<note markdown=“1”> For region availability, see [Supported Node Types]
</note>**R5 node types:**
cache.r5.large,cache.r5.xlarge,cache.r5.2xlarge,cache.r5.4xlarge,cache.r5.12xlarge,cache.r5.24xlarge**R4 node types:**
cache.r4.large,cache.r4.xlarge,cache.r4.2xlarge,cache.r4.4xlarge,cache.r4.8xlarge,cache.r4.16xlarge -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
**M2 node types:**
cache.m2.xlarge,cache.m2.2xlarge,cache.m2.4xlarge**R3 node types:**
cache.r3.large,cache.r3.xlarge,cache.r3.2xlarge,cache.r3.4xlarge,cache.r3.8xlarge
-
**Additional node type info**
-
All current generation instance types are created in Amazon VPC by default.
-
Redis append-only files (AOF) are not supported for T1 or T2 instances.
-
Redis Multi-AZ with automatic failover is not supported on T1 instances.
-
Redis configuration variables
appendonlyandappendfsyncare not supported on Redis version 2.8.22 and later.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_parameter_group_name ⇒ String
The name of the parameter group to associate with this cluster. If this argument is omitted, the default parameter group for the specified engine is used. You cannot use any parameter group which has ‘cluster-enabled=’yes’‘ when creating a cluster.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_security_group_names ⇒ Array<String>
A list of security group names to associate with this cluster.
Use this parameter only when you are creating a cluster outside of an Amazon Virtual Private Cloud (Amazon VPC).
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#cache_subnet_group_name ⇒ String
The name of the subnet group to be used for the cluster.
Use this parameter only when you are creating a cluster in an Amazon Virtual Private Cloud (Amazon VPC).
If you’re going to launch your cluster in an Amazon VPC, you need to create a subnet group before you start creating a cluster. For more information, see [Subnets and Subnet Groups].
[1]: docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SubnetGroups.html
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the cache engine to be used for this cluster.
Valid values for this parameter are: memcached | redis
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version number of the cache engine to be used for this cluster. To view the supported cache engine versions, use the DescribeCacheEngineVersions operation.
Important: You can upgrade to a newer engine version (see [Selecting a Cache Engine and Version]), but you cannot downgrade to an earlier engine version. If you want to use an earlier engine version, you must delete the existing cluster or replication group and create it anew with the earlier engine version.
[1]: docs.aws.amazon.com/AmazonElastiCache/latest/red-ug/SelectEngine.html#VersionManagement
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either ipv4 | ipv6. IPv6 is supported for workloads using Redis engine version 6.2 onward or Memcached engine version 1.6.6 on all instances built on the [Nitro system].
[1]: aws.amazon.com/ec2/nitro/
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfigurationRequest>
Specifies the destination, format and type of the logs.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Must be either ipv4 | ipv6 | dual_stack. IPv6 is supported for workloads using Redis engine version 6.2 onward or Memcached engine version 1.6.6 on all instances built on the [Nitro system].
[1]: aws.amazon.com/ec2/nitro/
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#notification_topic_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Simple Notification Service (SNS) topic to which notifications are sent.
<note markdown=“1”> The Amazon SNS topic owner must be the same as the cluster owner.
</note>
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#num_cache_nodes ⇒ Integer
The initial number of cache nodes that the cluster has.
For clusters running Redis, this value must be 1. For clusters running Memcached, this value must be between 1 and 40.
If you need more than 40 nodes for your Memcached cluster, please fill out the ElastiCache Limit Increase Request form at [aws.amazon.com/contact-us/elasticache-node-limit-request/][1].
[1]: aws.amazon.com/contact-us/elasticache-node-limit-request/
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#outpost_mode ⇒ String
Specifies whether the nodes in the cluster are created in a single outpost or across multiple outposts.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port number on which each of the cache nodes accepts connections.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_availability_zone ⇒ String
The EC2 Availability Zone in which the cluster is created.
All nodes belonging to this cluster are placed in the preferred Availability Zone. If you want to create your nodes across multiple Availability Zones, use PreferredAvailabilityZones.
Default: System chosen Availability Zone.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_availability_zones ⇒ Array<String>
A list of the Availability Zones in which cache nodes are created. The order of the zones in the list is not important.
This option is only supported on Memcached.
<note markdown=“1”> If you are creating your cluster in an Amazon VPC (recommended) you can only locate nodes in Availability Zones that are associated with the subnets in the selected subnet group.
The number of Availability Zones listed must equal the value of
NumCacheNodes.
</note>
If you want all the nodes in the same Availability Zone, use PreferredAvailabilityZone instead, or repeat the Availability Zone multiple times in the list.
Default: System chosen Availability Zones.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_maintenance_window ⇒ String
Specifies the weekly time range during which maintenance on the cluster is performed. It is specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute period.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_outpost_arn ⇒ String
The outpost ARN in which the cache cluster is created.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#preferred_outpost_arns ⇒ Array<String>
The outpost ARNs in which the cache cluster is created.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The ID of the replication group to which this cluster should belong. If this parameter is specified, the cluster is added to the specified replication group as a read replica; otherwise, the cluster is a standalone primary that is not part of any replication group.
If the specified replication group is Multi-AZ enabled and the Availability Zone is not specified, the cluster is created in Availability Zones that provide the best spread of read replicas across Availability Zones.
<note markdown=“1”> This parameter is only valid if the Engine parameter is redis.
</note>
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
One or more VPC security groups associated with the cluster.
Use this parameter only when you are creating a cluster in an Amazon Virtual Private Cloud (Amazon VPC).
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_arns ⇒ Array<String>
A single-element string list containing an Amazon Resource Name (ARN) that uniquely identifies a Redis RDB snapshot file stored in Amazon S3. The snapshot file is used to populate the node group (shard). The Amazon S3 object name in the ARN cannot contain any commas.
<note markdown=“1”> This parameter is only valid if the Engine parameter is redis.
</note>
Example of an Amazon S3 ARN: arn:aws:s3:::my_bucket/snapshot1.rdb
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
The name of a Redis snapshot from which to restore data into the new node group (shard). The snapshot status changes to restoring while the new node group (shard) is being created.
<note markdown=“1”> This parameter is only valid if the Engine parameter is redis.
</note>
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic snapshots before deleting them. For example, if you set SnapshotRetentionLimit to 5, a snapshot taken today is retained for 5 days before being deleted.
<note markdown=“1”> This parameter is only valid if the Engine parameter is redis.
</note>
Default: 0 (i.e., automatic backups are disabled for this cache cluster).
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your node group (shard).
Example: 05:00-09:00
If you do not specify this parameter, ElastiCache automatically chooses an appropriate time range.
<note markdown=“1”> This parameter is only valid if the Engine parameter is redis.
</note>
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true. You cannot modify the value of TransitEncryptionEnabled after the cluster is created. To enable in-transit encryption on a cluster you must set TransitEncryptionEnabled to true when you create a cluster.
Only available when creating a cache cluster in an Amazon VPC using Memcached version 1.6.12 or later.
2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 2125 2126 2127 2128 2129 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2096 class CreateCacheClusterMessage < Struct.new( :cache_cluster_id, :replication_group_id, :az_mode, :preferred_availability_zone, :preferred_availability_zones, :num_cache_nodes, :cache_node_type, :engine, :engine_version, :cache_parameter_group_name, :cache_subnet_group_name, :cache_security_group_names, :security_group_ids, :tags, :snapshot_arns, :snapshot_name, :preferred_maintenance_window, :port, :notification_topic_arn, :auto_minor_version_upgrade, :snapshot_retention_limit, :snapshot_window, :auth_token, :outpost_mode, :preferred_outpost_arn, :preferred_outpost_arns, :log_delivery_configurations, :transit_encryption_enabled, :network_type, :ip_discovery) SENSITIVE = [] include Aws::Structure end |