Class: Aws::ElastiCache::Types::CreateCacheSecurityGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::CreateCacheSecurityGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Note:
When making an API call, you may pass CreateCacheSecurityGroupMessage data as a hash:
{
cache_security_group_name: "String", # required
description: "String", # required
tags: [
{
key: "String",
value: "String",
},
],
}
Represents the input of a CreateCacheSecurityGroup operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_security_group_name ⇒ String
A name for the cache security group.
-
#description ⇒ String
A description for the cache security group.
-
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource.
Instance Attribute Details
#cache_security_group_name ⇒ String
A name for the cache security group. This value is stored as a lowercase string.
Constraints: Must contain no more than 255 alphanumeric characters. Cannot be the word “Default”.
Example: mysecuritygroup
2244 2245 2246 2247 2248 2249 2250 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2244 class CreateCacheSecurityGroupMessage < Struct.new( :cache_security_group_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description for the cache security group.
2244 2245 2246 2247 2248 2249 2250 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2244 class CreateCacheSecurityGroupMessage < Struct.new( :cache_security_group_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.
2244 2245 2246 2247 2248 2249 2250 |
# File 'lib/aws-sdk-elasticache/types.rb', line 2244 class CreateCacheSecurityGroupMessage < Struct.new( :cache_security_group_name, :description, :tags) SENSITIVE = [] include Aws::Structure end |