Class: Aws::ElastiCache::Types::CreateSnapshotMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::CreateSnapshotMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass CreateSnapshotMessage data as a hash:
{
replication_group_id: "String",
cache_cluster_id: "String",
snapshot_name: "String", # required
kms_key_id: "String",
tags: [
{
key: "String",
value: "String",
},
],
}
Represents the input of a CreateSnapshot operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_cluster_id ⇒ String
The identifier of an existing cluster.
-
#kms_key_id ⇒ String
The ID of the KMS key used to encrypt the snapshot.
-
#replication_group_id ⇒ String
The identifier of an existing replication group.
-
#snapshot_name ⇒ String
A name for the snapshot being created.
-
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource.
Instance Attribute Details
#cache_cluster_id ⇒ String
The identifier of an existing cluster. The snapshot is created from this cluster.
3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3081 class CreateSnapshotMessage < Struct.new( :replication_group_id, :cache_cluster_id, :snapshot_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ID of the KMS key used to encrypt the snapshot.
3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3081 class CreateSnapshotMessage < Struct.new( :replication_group_id, :cache_cluster_id, :snapshot_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The identifier of an existing replication group. The snapshot is created from this replication group.
3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3081 class CreateSnapshotMessage < Struct.new( :replication_group_id, :cache_cluster_id, :snapshot_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#snapshot_name ⇒ String
A name for the snapshot being created.
3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3081 class CreateSnapshotMessage < Struct.new( :replication_group_id, :cache_cluster_id, :snapshot_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.
3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3081 class CreateSnapshotMessage < Struct.new( :replication_group_id, :cache_cluster_id, :snapshot_name, :kms_key_id, :tags) SENSITIVE = [] include Aws::Structure end |