Class: Aws::ElastiCache::Types::DescribeCacheParametersMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Note:

When making an API call, you may pass DescribeCacheParametersMessage data as a hash:

{
  cache_parameter_group_name: "String", # required
  source: "String",
  max_records: 1,
  marker: "String",
}

Represents the input of a DescribeCacheParameters operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_parameter_group_nameString

The name of a specific cache parameter group to return details for.

Returns:

  • (String)


3930
3931
3932
3933
3934
3935
3936
3937
# File 'lib/aws-sdk-elasticache/types.rb', line 3930

class DescribeCacheParametersMessage < Struct.new(
  :cache_parameter_group_name,
  :source,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


3930
3931
3932
3933
3934
3935
3936
3937
# File 'lib/aws-sdk-elasticache/types.rb', line 3930

class DescribeCacheParametersMessage < Struct.new(
  :cache_parameter_group_name,
  :source,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: minimum 20; maximum 100.

Returns:

  • (Integer)


3930
3931
3932
3933
3934
3935
3936
3937
# File 'lib/aws-sdk-elasticache/types.rb', line 3930

class DescribeCacheParametersMessage < Struct.new(
  :cache_parameter_group_name,
  :source,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The parameter types to return.

Valid values: user | system | engine-default

Returns:

  • (String)


3930
3931
3932
3933
3934
3935
3936
3937
# File 'lib/aws-sdk-elasticache/types.rb', line 3930

class DescribeCacheParametersMessage < Struct.new(
  :cache_parameter_group_name,
  :source,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end