Class: Aws::ElastiCache::Types::DescribeCacheSubnetGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeCacheSubnetGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
When making an API call, you may pass DescribeCacheSubnetGroupsMessage data as a hash:
{
cache_subnet_group_name: "String",
max_records: 1,
marker: "String",
}
Represents the input of a DescribeCacheSubnetGroups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_subnet_group_name ⇒ String
The name of the cache subnet group to return details for.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#cache_subnet_group_name ⇒ String
The name of the cache subnet group to return details for.
4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4017 class DescribeCacheSubnetGroupsMessage < Struct.new( :cache_subnet_group_name, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4017 class DescribeCacheSubnetGroupsMessage < Struct.new( :cache_subnet_group_name, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: minimum 20; maximum 100.
4017 4018 4019 4020 4021 4022 4023 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4017 class DescribeCacheSubnetGroupsMessage < Struct.new( :cache_subnet_group_name, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |