Class: Aws::ElastiCache::Types::DescribeEngineDefaultParametersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeEngineDefaultParametersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Represents the input of a ‘DescribeEngineDefaultParameters` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_parameter_group_family ⇒ String
The name of the cache parameter group family.
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#cache_parameter_group_family ⇒ String
The name of the cache parameter group family.
Valid values are: ‘memcached1.4` | `memcached1.5` | `memcached1.6` | `redis2.6` | `redis2.8` | `redis3.2` | `redis4.0` | `redis5.0` | `redis6.x` | `redis6.2` | `redis7`
3934 3935 3936 3937 3938 3939 3940 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3934 class DescribeEngineDefaultParametersMessage < Struct.new( :cache_parameter_group_family, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
3934 3935 3936 3937 3938 3939 3940 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3934 class DescribeEngineDefaultParametersMessage < Struct.new( :cache_parameter_group_family, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: minimum 20; maximum 100.
3934 3935 3936 3937 3938 3939 3940 |
# File 'lib/aws-sdk-elasticache/types.rb', line 3934 class DescribeEngineDefaultParametersMessage < Struct.new( :cache_parameter_group_family, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |