Class: Aws::ElastiCache::Types::DescribeServiceUpdatesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeServiceUpdatesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Note:
When making an API call, you may pass DescribeServiceUpdatesMessage data as a hash:
{
service_update_name: "String",
service_update_status: ["available"], # accepts available, cancelled, expired
max_records: 1,
marker: "String",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#service_update_name ⇒ String
The unique ID of the service update.
-
#service_update_status ⇒ Array<String>
The status of the service update.
Instance Attribute Details
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
4684 4685 4686 4687 4688 4689 4690 4691 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4684 class DescribeServiceUpdatesMessage < Struct.new( :service_update_name, :service_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response
4684 4685 4686 4687 4688 4689 4690 4691 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4684 class DescribeServiceUpdatesMessage < Struct.new( :service_update_name, :service_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#service_update_name ⇒ String
The unique ID of the service update
4684 4685 4686 4687 4688 4689 4690 4691 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4684 class DescribeServiceUpdatesMessage < Struct.new( :service_update_name, :service_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#service_update_status ⇒ Array<String>
The status of the service update
4684 4685 4686 4687 4688 4689 4690 4691 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4684 class DescribeServiceUpdatesMessage < Struct.new( :service_update_name, :service_update_status, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |