Class: Aws::ElastiCache::Types::DescribeUserGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeUserGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#user_group_id ⇒ String
The ID of the user group.
Instance Attribute Details
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. >
4800 4801 4802 4803 4804 4805 4806 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4800 class DescribeUserGroupsMessage < Struct.new( :user_group_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.
4800 4801 4802 4803 4804 4805 4806 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4800 class DescribeUserGroupsMessage < Struct.new( :user_group_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#user_group_id ⇒ String
The ID of the user group.
4800 4801 4802 4803 4804 4805 4806 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4800 class DescribeUserGroupsMessage < Struct.new( :user_group_id, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |