Class: Aws::ElastiCache::Types::DescribeUserGroupsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Note:

When making an API call, you may pass DescribeUserGroupsMessage data as a hash:

{
  user_group_id: "String",
  max_records: 1,
  marker: "String",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. >

Returns:

  • (String)


4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-elasticache/types.rb', line 4901

class DescribeUserGroupsMessage < Struct.new(
  :user_group_id,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved.

Returns:

  • (Integer)


4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-elasticache/types.rb', line 4901

class DescribeUserGroupsMessage < Struct.new(
  :user_group_id,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#user_group_idString

The ID of the user group.

Returns:

  • (String)


4901
4902
4903
4904
4905
4906
4907
# File 'lib/aws-sdk-elasticache/types.rb', line 4901

class DescribeUserGroupsMessage < Struct.new(
  :user_group_id,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end