Class: Aws::ElastiCache::Types::DescribeUserGroupsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeUserGroupsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#user_groups ⇒ Array<Types::UserGroup>
Returns a list of user groups.
Instance Attribute Details
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.>
4821 4822 4823 4824 4825 4826 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4821 class DescribeUserGroupsResult < Struct.new( :user_groups, :marker) SENSITIVE = [] include Aws::Structure end |
#user_groups ⇒ Array<Types::UserGroup>
Returns a list of user groups.
4821 4822 4823 4824 4825 4826 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4821 class DescribeUserGroupsResult < Struct.new( :user_groups, :marker) SENSITIVE = [] include Aws::Structure end |