Class: Aws::ElastiCache::Types::DescribeUsersResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::DescribeUsersResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional marker returned from a prior request.
-
#users ⇒ Array<Types::User>
A list of users.
Instance Attribute Details
#marker ⇒ String
An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. >
4879 4880 4881 4882 4883 4884 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4879 class DescribeUsersResult < Struct.new( :users, :marker) SENSITIVE = [] include Aws::Structure end |
#users ⇒ Array<Types::User>
A list of users.
4879 4880 4881 4882 4883 4884 |
# File 'lib/aws-sdk-elasticache/types.rb', line 4879 class DescribeUsersResult < Struct.new( :users, :marker) SENSITIVE = [] include Aws::Structure end |