Class: Aws::ElastiCache::Types::ModifyGlobalReplicationGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Note:

When making an API call, you may pass ModifyGlobalReplicationGroupMessage data as a hash:

{
  global_replication_group_id: "String", # required
  apply_immediately: false, # required
  cache_node_type: "String",
  engine_version: "String",
  cache_parameter_group_name: "String",
  global_replication_group_description: "String",
  automatic_failover_enabled: false,
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apply_immediatelyBoolean

This parameter causes the modifications in this request and any pending modifications to be applied, asynchronously and as soon as possible. Modifications to Global Replication Groups cannot be requested to be applied in PreferredMaintenceWindow.

Returns:

  • (Boolean)


6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
# File 'lib/aws-sdk-elasticache/types.rb', line 6522

class ModifyGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :apply_immediately,
  :cache_node_type,
  :engine_version,
  :cache_parameter_group_name,
  :global_replication_group_description,
  :automatic_failover_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#automatic_failover_enabledBoolean

Determines whether a read replica is automatically promoted to read/write primary if the existing primary encounters a failure.

Returns:

  • (Boolean)


6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
# File 'lib/aws-sdk-elasticache/types.rb', line 6522

class ModifyGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :apply_immediately,
  :cache_node_type,
  :engine_version,
  :cache_parameter_group_name,
  :global_replication_group_description,
  :automatic_failover_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#cache_node_typeString

A valid cache node type that you want to scale this Global datastore to.

Returns:

  • (String)


6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
# File 'lib/aws-sdk-elasticache/types.rb', line 6522

class ModifyGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :apply_immediately,
  :cache_node_type,
  :engine_version,
  :cache_parameter_group_name,
  :global_replication_group_description,
  :automatic_failover_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#cache_parameter_group_nameString

The name of the cache parameter group to use with the Global datastore. It must be compatible with the major engine version used by the Global datastore.

Returns:

  • (String)


6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
# File 'lib/aws-sdk-elasticache/types.rb', line 6522

class ModifyGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :apply_immediately,
  :cache_node_type,
  :engine_version,
  :cache_parameter_group_name,
  :global_replication_group_description,
  :automatic_failover_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The upgraded version of the cache engine to be run on the clusters in the Global datastore.

Returns:

  • (String)


6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
# File 'lib/aws-sdk-elasticache/types.rb', line 6522

class ModifyGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :apply_immediately,
  :cache_node_type,
  :engine_version,
  :cache_parameter_group_name,
  :global_replication_group_description,
  :automatic_failover_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#global_replication_group_descriptionString

A description of the Global datastore

Returns:

  • (String)


6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
# File 'lib/aws-sdk-elasticache/types.rb', line 6522

class ModifyGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :apply_immediately,
  :cache_node_type,
  :engine_version,
  :cache_parameter_group_name,
  :global_replication_group_description,
  :automatic_failover_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#global_replication_group_idString

The name of the Global datastore

Returns:

  • (String)


6522
6523
6524
6525
6526
6527
6528
6529
6530
6531
6532
# File 'lib/aws-sdk-elasticache/types.rb', line 6522

class ModifyGlobalReplicationGroupMessage < Struct.new(
  :global_replication_group_id,
  :apply_immediately,
  :cache_node_type,
  :engine_version,
  :cache_parameter_group_name,
  :global_replication_group_description,
  :automatic_failover_enabled)
  SENSITIVE = []
  include Aws::Structure
end