Class: Aws::ElastiCache::Types::PendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::PendingModifiedValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
A group of settings that are applied to the cluster in the future, or that are currently being applied.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_token_status ⇒ String
The auth token status.
-
#cache_node_ids_to_remove ⇒ Array<String>
A list of cache node IDs that are being removed (or will be removed) from the cluster.
-
#cache_node_type ⇒ String
The cache node type that this cluster or replication group is scaled to.
-
#engine_version ⇒ String
The new cache engine version that the cluster runs.
-
#log_delivery_configurations ⇒ Array<Types::PendingLogDeliveryConfiguration>
The log delivery configurations being modified.
-
#num_cache_nodes ⇒ Integer
The new number of cache nodes for the cluster.
-
#scale_config ⇒ Types::ScaleConfig
The scaling configuration changes that are pending for the Memcached cluster.
-
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true.
-
#transit_encryption_mode ⇒ String
A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.
Instance Attribute Details
#auth_token_status ⇒ String
The auth token status
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#cache_node_ids_to_remove ⇒ Array<String>
A list of cache node IDs that are being removed (or will be removed) from the cluster. A node ID is a 4-digit numeric identifier (0001, 0002, etc.).
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
The cache node type that this cluster or replication group is scaled to.
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The new cache engine version that the cluster runs.
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::PendingLogDeliveryConfiguration>
The log delivery configurations being modified
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#num_cache_nodes ⇒ Integer
The new number of cache nodes for the cluster.
For clusters running Valkey or Redis OSS, this value must be 1. For clusters running Memcached, this value must be between 1 and 40.
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#scale_config ⇒ Types::ScaleConfig
The scaling configuration changes that are pending for the Memcached cluster.
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true.
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_mode ⇒ String
A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.
7406 7407 7408 7409 7410 7411 7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7406 class PendingModifiedValues < Struct.new( :num_cache_nodes, :cache_node_ids_to_remove, :engine_version, :cache_node_type, :auth_token_status, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :scale_config) SENSITIVE = [] include Aws::Structure end |