Class: Aws::ElastiCache::Types::PendingModifiedValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

A group of settings that are applied to the cluster in the future, or that are currently being applied.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_token_statusString

The auth token status

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
# File 'lib/aws-sdk-elasticache/types.rb', line 7562

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#cache_node_ids_to_removeArray<String>

A list of cache node IDs that are being removed (or will be removed) from the cluster. A node ID is a 4-digit numeric identifier (0001, 0002, etc.).

Returns:

  • (Array<String>)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
# File 'lib/aws-sdk-elasticache/types.rb', line 7562

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#cache_node_typeString

The cache node type that this cluster or replication group is scaled to.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
# File 'lib/aws-sdk-elasticache/types.rb', line 7562

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The new cache engine version that the cluster runs.

Returns:

  • (String)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
# File 'lib/aws-sdk-elasticache/types.rb', line 7562

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#log_delivery_configurationsArray<Types::PendingLogDeliveryConfiguration>

The log delivery configurations being modified



7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
# File 'lib/aws-sdk-elasticache/types.rb', line 7562

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#num_cache_nodesInteger

The new number of cache nodes for the cluster.

For clusters running Redis, this value must be 1. For clusters running Memcached, this value must be between 1 and 40.

Returns:

  • (Integer)


7562
7563
7564
7565
7566
7567
7568
7569
7570
7571
# File 'lib/aws-sdk-elasticache/types.rb', line 7562

class PendingModifiedValues < Struct.new(
  :num_cache_nodes,
  :cache_node_ids_to_remove,
  :engine_version,
  :cache_node_type,
  :auth_token_status,
  :log_delivery_configurations)
  SENSITIVE = []
  include Aws::Structure
end