Class: Aws::ElastiCache::Types::ReplicationGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ReplicationGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Contains all of the attributes of a specific Valkey or Redis OSS replication group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The ARN (Amazon Resource Name) of the replication group.
-
#at_rest_encryption_enabled ⇒ Boolean
A flag that enables encryption at-rest on the cluster when set to
true. -
#auth_token_enabled ⇒ Boolean
A flag that enables using an
AuthToken(password) when issuing Valkey or Redis OSS commands. -
#auth_token_last_modified_date ⇒ Time
The date the auth token was last modified.
-
#auto_minor_version_upgrade ⇒ Boolean
If you are running Valkey 7.2 and above, or Redis OSS engine version 6.0 and above, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign.
-
#automatic_failover ⇒ String
Indicates the status of automatic failover for this Valkey or Redis OSS replication group.
-
#cache_node_type ⇒ String
The name of the compute and memory capacity node type for each node in the replication group.
-
#cluster_enabled ⇒ Boolean
A flag indicating whether or not this replication group is cluster enabled; i.e., whether its data can be partitioned across multiple shards (API/CLI: node groups).
-
#cluster_mode ⇒ String
Enabled or Disabled.
-
#configuration_endpoint ⇒ Types::Endpoint
The configuration endpoint for this replication group.
-
#data_tiering ⇒ String
Enables data tiering.
-
#description ⇒ String
The user supplied description of the replication group.
-
#durability ⇒ String
The durability setting of the replication group.
-
#effective_durability ⇒ String
The effective durability of the replication group.
-
#engine ⇒ String
The engine used in a replication group.
-
#global_replication_group_info ⇒ Types::GlobalReplicationGroupInfo
The name of the Global datastore and role of this replication group in the Global datastore.
-
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either
ipv4|ipv6. -
#kms_key_id ⇒ String
The ID of the KMS key used to encrypt the disk in the cluster.
-
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfiguration>
Returns the destination, format and type of the logs.
-
#member_clusters ⇒ Array<String>
The names of all the cache clusters that are part of this replication group.
-
#member_clusters_outpost_arns ⇒ Array<String>
The outpost ARNs of the replication group's member clusters.
-
#multi_az ⇒ String
A flag indicating if you have Multi-AZ enabled to enhance fault tolerance.
-
#network_type ⇒ String
Must be either
ipv4|ipv6|dual_stack. -
#node_groups ⇒ Array<Types::NodeGroup>
A list of node groups in this replication group.
-
#pending_modified_values ⇒ Types::ReplicationGroupPendingModifiedValues
A group of settings to be applied to the replication group, either immediately or during the next maintenance window.
-
#replication_group_create_time ⇒ Time
The date and time when the cluster was created.
-
#replication_group_id ⇒ String
The identifier for the replication group.
-
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic cluster snapshots before deleting them.
-
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your node group (shard).
-
#snapshotting_cluster_id ⇒ String
The cluster ID that is used as the daily snapshot source for the replication group.
-
#status ⇒ String
The current state of this replication group -
creating,available,modifying,deleting,create-failed,snapshotting. -
#storage_encryption_type ⇒ String
Indicates the type of encryption for data stored at rest in the replication group.
-
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to
true. -
#transit_encryption_mode ⇒ String
A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.
-
#user_group_ids ⇒ Array<String>
The ID of the user group associated to the replication group.
Instance Attribute Details
#arn ⇒ String
The ARN (Amazon Resource Name) of the replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#at_rest_encryption_enabled ⇒ Boolean
A flag that enables encryption at-rest on the cluster when set to
true. In some cases, encryption at-rest may be enabled even when
this value is false. Use StorageEncryptionType to view the
effective encryption state of a cluster.
You cannot modify the value of AtRestEncryptionEnabled after the
cluster is created.
Default: true when using Valkey, false when using Redis OSS
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#auth_token_enabled ⇒ Boolean
A flag that enables using an AuthToken (password) when issuing
Valkey or Redis OSS commands.
Default: false
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#auth_token_last_modified_date ⇒ Time
The date the auth token was last modified
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
If you are running Valkey 7.2 and above, or Redis OSS engine version 6.0 and above, set this parameter to yes if you want to opt-in to the next auto minor version upgrade campaign. This parameter is disabled for previous versions.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#automatic_failover ⇒ String
Indicates the status of automatic failover for this Valkey or Redis OSS replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
The name of the compute and memory capacity node type for each node in the replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#cluster_enabled ⇒ Boolean
A flag indicating whether or not this replication group is cluster enabled; i.e., whether its data can be partitioned across multiple shards (API/CLI: node groups).
Valid values: true | false
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#cluster_mode ⇒ String
Enabled or Disabled. To modify cluster mode from Disabled to Enabled, you must first set the cluster mode to Compatible. Compatible mode allows your Valkey or Redis OSS clients to connect using both cluster mode enabled and cluster mode disabled. After you migrate all Valkey or Redis OSS clients to use cluster mode enabled, you can then complete cluster mode configuration and set the cluster mode to Enabled.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#configuration_endpoint ⇒ Types::Endpoint
The configuration endpoint for this replication group. Use the configuration endpoint to connect to this replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#data_tiering ⇒ String
Enables data tiering. Data tiering is only supported for replication groups using the r6gd node type. This parameter must be set to true when using r6gd nodes. For more information, see Data tiering.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The user supplied description of the replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#durability ⇒ String
The durability setting of the replication group. For more information, see Durability.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#effective_durability ⇒ String
The effective durability of the replication group. When Durability
is set to default, the service resolves the actual durability
based on the engine version, cluster mode, and other parameters.
This field reflects the resolved value. For more information, see
Configuring Durability.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The engine used in a replication group. The options are valkey, memcached or redis.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#global_replication_group_info ⇒ Types::GlobalReplicationGroupInfo
The name of the Global datastore and role of this replication group in the Global datastore.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#ip_discovery ⇒ String
The network type you choose when modifying a cluster, either ipv4
| ipv6. IPv6 is supported for workloads using Valkey 7.2 and
above, Redis OSS engine version 6.2 to 7.1 or Memcached engine
version 1.6.6 and above on all instances built on the Nitro
system.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The ID of the KMS key used to encrypt the disk in the cluster.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::LogDeliveryConfiguration>
Returns the destination, format and type of the logs.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#member_clusters ⇒ Array<String>
The names of all the cache clusters that are part of this replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#member_clusters_outpost_arns ⇒ Array<String>
The outpost ARNs of the replication group's member clusters.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#multi_az ⇒ String
A flag indicating if you have Multi-AZ enabled to enhance fault tolerance. For more information, see Minimizing Downtime: Multi-AZ
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#network_type ⇒ String
Must be either ipv4 | ipv6 | dual_stack. IPv6 is supported
for workloads using Valkey 7.2 and above, Redis OSS engine version
6.2 to 7.1 or Memcached engine version 1.6.6 and above on all
instances built on the Nitro system.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#node_groups ⇒ Array<Types::NodeGroup>
A list of node groups in this replication group. For Valkey or Redis OSS (cluster mode disabled) replication groups, this is a single-element list. For Valkey or Redis OSS (cluster mode enabled) replication groups, the list contains an entry for each node group (shard).
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#pending_modified_values ⇒ Types::ReplicationGroupPendingModifiedValues
A group of settings to be applied to the replication group, either immediately or during the next maintenance window.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#replication_group_create_time ⇒ Time
The date and time when the cluster was created.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The identifier for the replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#snapshot_retention_limit ⇒ Integer
The number of days for which ElastiCache retains automatic cluster
snapshots before deleting them. For example, if you set
SnapshotRetentionLimit to 5, a snapshot that was taken today is
retained for 5 days before being deleted.
If the value of SnapshotRetentionLimit is set to zero (0), backups
are turned off.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#snapshot_window ⇒ String
The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your node group (shard).
Example: 05:00-09:00
If you do not specify this parameter, ElastiCache automatically chooses an appropriate time range.
Engine parameter is redis.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#snapshotting_cluster_id ⇒ String
The cluster ID that is used as the daily snapshot source for the replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current state of this replication group - creating,
available, modifying, deleting, create-failed,
snapshotting.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#storage_encryption_type ⇒ String
Indicates the type of encryption for data stored at rest in the
replication group. The value is none if at-rest encryption is not
enabled, sse-elasticache if an ElastiCache service-managed key is
used, or sse-kms if a customer-managed KMS key is used.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true.
Required: Only available when creating a replication group in an
Amazon VPC using Redis OSS version 3.2.6, 4.x or later.
Default: false
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_mode ⇒ String
A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |
#user_group_ids ⇒ Array<String>
The ID of the user group associated to the replication group.
7908 7909 7910 7911 7912 7913 7914 7915 7916 7917 7918 7919 7920 7921 7922 7923 7924 7925 7926 7927 7928 7929 7930 7931 7932 7933 7934 7935 7936 7937 7938 7939 7940 7941 7942 7943 7944 7945 7946 |
# File 'lib/aws-sdk-elasticache/types.rb', line 7908 class ReplicationGroup < Struct.new( :replication_group_id, :description, :global_replication_group_info, :status, :pending_modified_values, :member_clusters, :node_groups, :snapshotting_cluster_id, :automatic_failover, :multi_az, :configuration_endpoint, :snapshot_retention_limit, :snapshot_window, :cluster_enabled, :cache_node_type, :auth_token_enabled, :auth_token_last_modified_date, :transit_encryption_enabled, :at_rest_encryption_enabled, :member_clusters_outpost_arns, :kms_key_id, :storage_encryption_type, :arn, :user_group_ids, :log_delivery_configurations, :replication_group_create_time, :data_tiering, :auto_minor_version_upgrade, :network_type, :ip_discovery, :transit_encryption_mode, :cluster_mode, :engine, :durability, :effective_durability) SENSITIVE = [] include Aws::Structure end |