Class: Aws::ElastiCache::Types::ReplicationGroupPendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ReplicationGroupPendingModifiedValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
The settings to be applied to the Valkey or Redis OSS replication group, either immediately or during the next maintenance window.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_token_status ⇒ String
The auth token status.
-
#automatic_failover_status ⇒ String
Indicates the status of automatic failover for this Valkey or Redis OSS replication group.
-
#cluster_mode ⇒ String
Enabled or Disabled.
-
#log_delivery_configurations ⇒ Array<Types::PendingLogDeliveryConfiguration>
The log delivery configurations being modified.
-
#primary_cluster_id ⇒ String
The primary cluster ID that is applied immediately (if ‘–apply-immediately` was specified), or during the next maintenance window.
-
#resharding ⇒ Types::ReshardingStatus
The status of an online resharding operation.
-
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true.
-
#transit_encryption_mode ⇒ String
A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.
-
#user_groups ⇒ Types::UserGroupsUpdateStatus
The user group being modified.
Instance Attribute Details
#auth_token_status ⇒ String
The auth token status
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#automatic_failover_status ⇒ String
Indicates the status of automatic failover for this Valkey or Redis OSS replication group.
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#cluster_mode ⇒ String
Enabled or Disabled. To modify cluster mode from Disabled to Enabled, you must first set the cluster mode to Compatible. Compatible mode allows your Valkey or Redis OSS clients to connect using both cluster mode enabled and cluster mode disabled. After you migrate all Valkey or Redis OSS clients to use cluster mode enabled, you can then complete cluster mode configuration and set the cluster mode to Enabled.
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::PendingLogDeliveryConfiguration>
The log delivery configurations being modified
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#primary_cluster_id ⇒ String
The primary cluster ID that is applied immediately (if ‘–apply-immediately` was specified), or during the next maintenance window.
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#resharding ⇒ Types::ReshardingStatus
The status of an online resharding operation.
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_enabled ⇒ Boolean
A flag that enables in-transit encryption when set to true.
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#transit_encryption_mode ⇒ String
A setting that allows you to migrate your clients to use in-transit encryption, with no downtime.
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |
#user_groups ⇒ Types::UserGroupsUpdateStatus
The user group being modified.
8038 8039 8040 8041 8042 8043 8044 8045 8046 8047 8048 8049 8050 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8038 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations, :transit_encryption_enabled, :transit_encryption_mode, :cluster_mode) SENSITIVE = [] include Aws::Structure end |