Class: Aws::ElastiCache::Types::ReplicationGroupPendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ReplicationGroupPendingModifiedValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
The settings to be applied to the Redis replication group, either immediately or during the next maintenance window.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_token_status ⇒ String
The auth token status.
-
#automatic_failover_status ⇒ String
Indicates the status of automatic failover for this Redis replication group.
-
#log_delivery_configurations ⇒ Array<Types::PendingLogDeliveryConfiguration>
The log delivery configurations being modified.
-
#primary_cluster_id ⇒ String
The primary cluster ID that is applied immediately (if
--apply-immediatelywas specified), or during the next maintenance window. -
#resharding ⇒ Types::ReshardingStatus
The status of an online resharding operation.
-
#user_groups ⇒ Types::UserGroupsUpdateStatus
The user group being modified.
Instance Attribute Details
#auth_token_status ⇒ String
The auth token status
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8175 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations) SENSITIVE = [] include Aws::Structure end |
#automatic_failover_status ⇒ String
Indicates the status of automatic failover for this Redis replication group.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8175 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations) SENSITIVE = [] include Aws::Structure end |
#log_delivery_configurations ⇒ Array<Types::PendingLogDeliveryConfiguration>
The log delivery configurations being modified
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8175 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations) SENSITIVE = [] include Aws::Structure end |
#primary_cluster_id ⇒ String
The primary cluster ID that is applied immediately (if --apply-immediately was specified), or during the next maintenance window.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8175 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations) SENSITIVE = [] include Aws::Structure end |
#resharding ⇒ Types::ReshardingStatus
The status of an online resharding operation.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8175 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations) SENSITIVE = [] include Aws::Structure end |
#user_groups ⇒ Types::UserGroupsUpdateStatus
The user group being modified.
8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8175 class ReplicationGroupPendingModifiedValues < Struct.new( :primary_cluster_id, :automatic_failover_status, :resharding, :auth_token_status, :user_groups, :log_delivery_configurations) SENSITIVE = [] include Aws::Structure end |