Class: Aws::ElastiCache::Types::ReservedCacheNode
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ReservedCacheNode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Represents the output of a PurchaseReservedCacheNodesOffering
operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_node_count ⇒ Integer
The number of cache nodes that have been reserved.
-
#cache_node_type ⇒ String
The cache node type for the reserved cache nodes.
-
#duration ⇒ Integer
The duration of the reservation in seconds.
-
#fixed_price ⇒ Float
The fixed price charged for this reserved cache node.
-
#offering_type ⇒ String
The offering type of this reserved cache node.
-
#product_description ⇒ String
The description of the reserved cache node.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring price charged to run this reserved cache node.
-
#reservation_arn ⇒ String
The Amazon Resource Name (ARN) of the reserved cache node.
-
#reserved_cache_node_id ⇒ String
The unique identifier for the reservation.
-
#reserved_cache_nodes_offering_id ⇒ String
The offering identifier.
-
#start_time ⇒ Time
The time the reservation started.
-
#state ⇒ String
The state of the reserved cache node.
-
#usage_price ⇒ Float
The hourly price charged for this reserved cache node.
Instance Attribute Details
#cache_node_count ⇒ Integer
The number of cache nodes that have been reserved.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#cache_node_type ⇒ String
The cache node type for the reserved cache nodes.
The following node types are supported by ElastiCache. Generally speaking, the current generation types provide more memory and computational power at lower cost when compared to their equivalent previous generation counterparts.
-
General purpose:
-
Current generation:
M7g node types:
cache.m7g.large,cache.m7g.xlarge,cache.m7g.2xlarge,cache.m7g.4xlarge,cache.m7g.8xlarge,cache.m7g.12xlarge,cache.m7g.16xlargeFor region availability, see Supported Node Types M6g node types (available only for Redis OSS engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward):
cache.m6g.large,cache.m6g.xlarge,cache.m6g.2xlarge,cache.m6g.4xlarge,cache.m6g.8xlarge,cache.m6g.12xlarge,cache.m6g.16xlargeM5 node types:
cache.m5.large,cache.m5.xlarge,cache.m5.2xlarge,cache.m5.4xlarge,cache.m5.12xlarge,cache.m5.24xlargeM4 node types:
cache.m4.large,cache.m4.xlarge,cache.m4.2xlarge,cache.m4.4xlarge,cache.m4.10xlargeT4g node types (available only for Redis OSS engine version 5.0.6 onward and Memcached engine version 1.5.16 onward):
cache.t4g.micro,cache.t4g.small,cache.t4g.mediumT3 node types:
cache.t3.micro,cache.t3.small,cache.t3.mediumT2 node types:
cache.t2.micro,cache.t2.small,cache.t2.medium -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
T1 node types:
cache.t1.microM1 node types:
cache.m1.small,cache.m1.medium,cache.m1.large,cache.m1.xlargeM3 node types:
cache.m3.medium,cache.m3.large,cache.m3.xlarge,cache.m3.2xlarge -
Compute optimized:
-
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
C1 node types:
cache.c1.xlarge -
Memory optimized:
-
Current generation:
R7g node types:
cache.r7g.large,cache.r7g.xlarge,cache.r7g.2xlarge,cache.r7g.4xlarge,cache.r7g.8xlarge,cache.r7g.12xlarge,cache.r7g.16xlargeFor region availability, see Supported Node Types R6g node types (available only for Redis OSS engine version 5.0.6 onward and for Memcached engine version 1.5.16 onward):
cache.r6g.large,cache.r6g.xlarge,cache.r6g.2xlarge,cache.r6g.4xlarge,cache.r6g.8xlarge,cache.r6g.12xlarge,cache.r6g.16xlargeR5 node types:
cache.r5.large,cache.r5.xlarge,cache.r5.2xlarge,cache.r5.4xlarge,cache.r5.12xlarge,cache.r5.24xlargeR4 node types:
cache.r4.large,cache.r4.xlarge,cache.r4.2xlarge,cache.r4.4xlarge,cache.r4.8xlarge,cache.r4.16xlarge -
Previous generation: (not recommended. Existing clusters are still supported but creation of new clusters is not supported for these types.)
M2 node types:
cache.m2.xlarge,cache.m2.2xlarge,cache.m2.4xlargeR3 node types:
cache.r3.large,cache.r3.xlarge,cache.r3.2xlarge,cache.r3.4xlarge,cache.r3.8xlarge
Additional node type info
-
All current generation instance types are created in Amazon VPC by default.
-
Valkey or Redis OSS append-only files (AOF) are not supported for T1 or T2 instances.
-
Valkey or Redis OSS Multi-AZ with automatic failover is not supported on T1 instances.
-
The configuration variables
appendonlyandappendfsyncare not supported on Valkey, or on Redis OSS version 2.8.22 and later.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration of the reservation in seconds.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The fixed price charged for this reserved cache node.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The offering type of this reserved cache node.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
The description of the reserved cache node.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring price charged to run this reserved cache node.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#reservation_arn ⇒ String
The Amazon Resource Name (ARN) of the reserved cache node.
Example:
arn:aws:elasticache:us-east-1:123456789012:reserved-instance:ri-2017-03-27-08-33-25-582
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#reserved_cache_node_id ⇒ String
The unique identifier for the reservation.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#reserved_cache_nodes_offering_id ⇒ String
The offering identifier.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time the reservation started.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the reserved cache node.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The hourly price charged for this reserved cache node.
8229 8230 8231 8232 8233 8234 8235 8236 8237 8238 8239 8240 8241 8242 8243 8244 8245 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8229 class ReservedCacheNode < Struct.new( :reserved_cache_node_id, :reserved_cache_nodes_offering_id, :cache_node_type, :start_time, :duration, :fixed_price, :usage_price, :cache_node_count, :product_description, :offering_type, :state, :recurring_charges, :reservation_arn) SENSITIVE = [] include Aws::Structure end |