Class: Aws::ElastiCache::Types::ServiceUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::ServiceUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
An update that you can apply to your Valkey or Redis OSS clusters.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_update_after_recommended_apply_by_date ⇒ Boolean
Indicates whether the service update will be automatically applied once the recommended apply-by date has expired.
-
#engine ⇒ String
The Elasticache engine to which the update applies.
-
#engine_version ⇒ String
The Elasticache engine version to which the update applies.
-
#estimated_update_time ⇒ String
The estimated length of time the service update will take.
-
#service_update_description ⇒ String
Provides details of the service update.
-
#service_update_end_date ⇒ Time
The date after which the service update is no longer available.
-
#service_update_name ⇒ String
The unique ID of the service update.
-
#service_update_recommended_apply_by_date ⇒ Time
The recommendend date to apply the service update in order to ensure compliance.
-
#service_update_release_date ⇒ Time
The date when the service update is initially available.
-
#service_update_severity ⇒ String
The severity of the service update.
-
#service_update_status ⇒ String
The status of the service update.
-
#service_update_type ⇒ String
Reflects the nature of the service update.
Instance Attribute Details
#auto_update_after_recommended_apply_by_date ⇒ Boolean
Indicates whether the service update will be automatically applied once the recommended apply-by date has expired.
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The Elasticache engine to which the update applies. Either Valkey, Redis OSS or Memcached.
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The Elasticache engine version to which the update applies. Either Valkey, Redis OSS or Memcached engine version.
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#estimated_update_time ⇒ String
The estimated length of time the service update will take
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_description ⇒ String
Provides details of the service update
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_end_date ⇒ Time
The date after which the service update is no longer available
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_name ⇒ String
The unique ID of the service update
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_recommended_apply_by_date ⇒ Time
The recommendend date to apply the service update in order to ensure compliance. For information on compliance, see [Self-Service Security Updates for Compliance].
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_release_date ⇒ Time
The date when the service update is initially available
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_severity ⇒ String
The severity of the service update
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_status ⇒ String
The status of the service update
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |
#service_update_type ⇒ String
Reflects the nature of the service update
8948 8949 8950 8951 8952 8953 8954 8955 8956 8957 8958 8959 8960 8961 8962 8963 |
# File 'lib/aws-sdk-elasticache/types.rb', line 8948 class ServiceUpdate < Struct.new( :service_update_name, :service_update_release_date, :service_update_end_date, :service_update_severity, :service_update_recommended_apply_by_date, :service_update_status, :service_update_description, :service_update_type, :engine, :engine_version, :auto_update_after_recommended_apply_by_date, :estimated_update_time) SENSITIVE = [] include Aws::Structure end |