Class: Aws::ElastiCache::Types::ServiceUpdatesMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


8859
8860
8861
8862
8863
8864
# File 'lib/aws-sdk-elasticache/types.rb', line 8859

class ServiceUpdatesMessage < Struct.new(
  :marker,
  :service_updates)
  SENSITIVE = []
  include Aws::Structure
end

#service_updatesArray<Types::ServiceUpdate>

A list of service updates

Returns:



8859
8860
8861
8862
8863
8864
# File 'lib/aws-sdk-elasticache/types.rb', line 8859

class ServiceUpdatesMessage < Struct.new(
  :marker,
  :service_updates)
  SENSITIVE = []
  include Aws::Structure
end