Class: Aws::ElastiCache::Types::TestFailoverMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#node_group_idString

The name of the node group (called shard in the console) in this replication group on which automatic failover is to be tested. You may test automatic failover on up to 15 node groups in any rolling 24-hour period.

Returns:

  • (String)


9537
9538
9539
9540
9541
9542
# File 'lib/aws-sdk-elasticache/types.rb', line 9537

class TestFailoverMessage < Struct.new(
  :replication_group_id,
  :node_group_id)
  SENSITIVE = []
  include Aws::Structure
end

#replication_group_idString

The name of the replication group (console: cluster) whose automatic failover is being tested by this operation.

Returns:

  • (String)


9537
9538
9539
9540
9541
9542
# File 'lib/aws-sdk-elasticache/types.rb', line 9537

class TestFailoverMessage < Struct.new(
  :replication_group_id,
  :node_group_id)
  SENSITIVE = []
  include Aws::Structure
end