Class: Aws::ElastiCache::Types::TestFailoverMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::ElastiCache::Types::TestFailoverMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-elasticache/types.rb
Overview
Note:
When making an API call, you may pass TestFailoverMessage data as a hash:
{
replication_group_id: "String", # required
node_group_id: "AllowedNodeGroupId", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#node_group_id ⇒ String
The name of the node group (called shard in the console) in this replication group on which automatic failover is to be tested.
-
#replication_group_id ⇒ String
The name of the replication group (console: cluster) whose automatic failover is being tested by this operation.
Instance Attribute Details
#node_group_id ⇒ String
The name of the node group (called shard in the console) in this replication group on which automatic failover is to be tested. You may test automatic failover on up to 5 node groups in any rolling 24-hour period.
9422 9423 9424 9425 9426 9427 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9422 class TestFailoverMessage < Struct.new( :replication_group_id, :node_group_id) SENSITIVE = [] include Aws::Structure end |
#replication_group_id ⇒ String
The name of the replication group (console: cluster) whose automatic failover is being tested by this operation.
9422 9423 9424 9425 9426 9427 |
# File 'lib/aws-sdk-elasticache/types.rb', line 9422 class TestFailoverMessage < Struct.new( :replication_group_id, :node_group_id) SENSITIVE = [] include Aws::Structure end |