Class: Aws::ElastiCache::Types::UpdateActionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-elasticache/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


9647
9648
9649
9650
9651
9652
# File 'lib/aws-sdk-elasticache/types.rb', line 9647

class UpdateActionsMessage < Struct.new(
  :marker,
  :update_actions)
  SENSITIVE = []
  include Aws::Structure
end

#update_actionsArray<Types::UpdateAction>

Returns a list of update actions

Returns:



9647
9648
9649
9650
9651
9652
# File 'lib/aws-sdk-elasticache/types.rb', line 9647

class UpdateActionsMessage < Struct.new(
  :marker,
  :update_actions)
  SENSITIVE = []
  include Aws::Structure
end