Class: Aws::ElastiCache::Waiters::CacheClusterDeleted
- Inherits:
-
Object
- Object
- Aws::ElastiCache::Waiters::CacheClusterDeleted
- Defined in:
- lib/aws-sdk-elasticache/waiters.rb,
sig/waiters.rbs
Overview
Wait until ElastiCache cluster is deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CacheClusterDeleted
constructor
A new instance of CacheClusterDeleted.
-
#wait(params = {}) ⇒ Types::CacheClusterMessage
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CacheClusterDeleted
Returns a new instance of CacheClusterDeleted.
151 152 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 151
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
218 219 220 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 218 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::CacheClusterMessage
Returns a response object which responds to the following methods:
- #marker => String
- #cache_clusters => Array<Types::CacheCluster>
213 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 213
def wait: (
|