Class: Aws::ElastiCache::Waiters::ReplicationGroupAvailable
- Inherits:
-
Object
- Object
- Aws::ElastiCache::Waiters::ReplicationGroupAvailable
- Defined in:
- lib/aws-sdk-elasticache/waiters.rb,
sig/waiters.rbs
Overview
Wait until ElastiCache replication group is available.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ReplicationGroupAvailable
constructor
A new instance of ReplicationGroupAvailable.
-
#wait(params = {}) ⇒ Types::ReplicationGroupMessage
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ReplicationGroupAvailable
Returns a new instance of ReplicationGroupAvailable.
231 232 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 231
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
263 264 265 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 263 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::ReplicationGroupMessage
Returns a response object which responds to the following methods:
- #marker => String
- #replication_groups => Array<Types::ReplicationGroup>
258 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 258
def wait: (
|