Class: Aws::ElastiCache::Waiters::ReplicationGroupDeleted
- Inherits:
-
Object
- Object
- Aws::ElastiCache::Waiters::ReplicationGroupDeleted
- Defined in:
- lib/aws-sdk-elasticache/waiters.rb,
sig/waiters.rbs
Overview
Wait until ElastiCache replication group is deleted.
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ReplicationGroupDeleted
constructor
A new instance of ReplicationGroupDeleted.
-
#wait(params = {}) ⇒ Types::ReplicationGroupMessage
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ReplicationGroupDeleted
Returns a new instance of ReplicationGroupDeleted.
276 277 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 276
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
313 314 315 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 313 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::ReplicationGroupMessage
Returns a response object which responds to the following methods:
- #marker => String
- #replication_groups => Array<Types::ReplicationGroup>
308 |
# File 'lib/aws-sdk-elasticache/waiters.rb', line 308
def wait: (
|